/* ANSI-C code produced by gperf version 3.3 */
/* Command-line: gperf --output-file src/network/networkd-network-gperf.c ../systemd/src/network/networkd-network-gperf.gperf  */
/* Computed positions: -k'1,6-7,10,12,16,20,24,29,$' */

#if !((' ' == 32) && ('!' == 33) && ('"' == 34) && ('#' == 35) \
      && ('%' == 37) && ('&' == 38) && ('\'' == 39) && ('(' == 40) \
      && (')' == 41) && ('*' == 42) && ('+' == 43) && (',' == 44) \
      && ('-' == 45) && ('.' == 46) && ('/' == 47) && ('0' == 48) \
      && ('1' == 49) && ('2' == 50) && ('3' == 51) && ('4' == 52) \
      && ('5' == 53) && ('6' == 54) && ('7' == 55) && ('8' == 56) \
      && ('9' == 57) && (':' == 58) && (';' == 59) && ('<' == 60) \
      && ('=' == 61) && ('>' == 62) && ('?' == 63) && ('A' == 65) \
      && ('B' == 66) && ('C' == 67) && ('D' == 68) && ('E' == 69) \
      && ('F' == 70) && ('G' == 71) && ('H' == 72) && ('I' == 73) \
      && ('J' == 74) && ('K' == 75) && ('L' == 76) && ('M' == 77) \
      && ('N' == 78) && ('O' == 79) && ('P' == 80) && ('Q' == 81) \
      && ('R' == 82) && ('S' == 83) && ('T' == 84) && ('U' == 85) \
      && ('V' == 86) && ('W' == 87) && ('X' == 88) && ('Y' == 89) \
      && ('Z' == 90) && ('[' == 91) && ('\\' == 92) && (']' == 93) \
      && ('^' == 94) && ('_' == 95) && ('a' == 97) && ('b' == 98) \
      && ('c' == 99) && ('d' == 100) && ('e' == 101) && ('f' == 102) \
      && ('g' == 103) && ('h' == 104) && ('i' == 105) && ('j' == 106) \
      && ('k' == 107) && ('l' == 108) && ('m' == 109) && ('n' == 110) \
      && ('o' == 111) && ('p' == 112) && ('q' == 113) && ('r' == 114) \
      && ('s' == 115) && ('t' == 116) && ('u' == 117) && ('v' == 118) \
      && ('w' == 119) && ('x' == 120) && ('y' == 121) && ('z' == 122) \
      && ('{' == 123) && ('|' == 124) && ('}' == 125) && ('~' == 126))
/* The character set is not based on ISO-646.  */
#error "gperf generated tables don't work with this execution character set. Please report a bug to <bug-gperf@gnu.org>."
#endif

#line 2 "../systemd/src/network/networkd-network-gperf.gperf"

_Pragma("GCC diagnostic ignored \"-Wimplicit-fallthrough\"")
#if __GNUC__ >= 15
_Pragma("GCC diagnostic ignored \"-Wzero-as-null-pointer-constant\"")
#endif
#include <linux/can/netlink.h>
#include <netinet/icmp6.h>
#include <stddef.h>

#include "sd-dhcp-lease.h"

#include "condition.h"
#include "conf-parser.h"
#include "in-addr-prefix-util.h"
#include "net-condition.h"
#include "netif-sriov.h"
#include "networkd-address-generation.h"
#include "networkd-address-label.h"
#include "networkd-address.h"
#include "networkd-bridge-fdb.h"
#include "networkd-bridge-mdb.h"
#include "networkd-can.h"
#include "networkd-dhcp-common.h"
#include "networkd-dhcp-prefix-delegation.h"
#include "networkd-dhcp-server-static-lease.h"
#include "networkd-dhcp-server.h"
#include "networkd-dhcp4.h"
#include "networkd-dhcp6.h"
#include "networkd-dns.h"
#include "networkd-ipv4ll.h"
#include "networkd-ipv6-proxy-ndp.h"
#include "networkd-ipv6ll.h"
#include "networkd-lldp-tx.h"
#include "networkd-ndisc.h"
#include "networkd-network.h"
#include "networkd-neighbor.h"
#include "networkd-nexthop.h"
#include "networkd-ntp.h"
#include "networkd-radv.h"
#include "networkd-route.h"
#include "networkd-routing-policy-rule.h"
#include "networkd-wwan.h"
#include "qdisc.h"
#include "socket-util.h"
#include "tclass.h"

#include "cake.h"
#include "codel.h"
#include "ets.h"
#include "fifo.h"
#include "fq-codel.h"
#include "fq-pie.h"
#include "fq.h"
#include "gred.h"
#include "hhf.h"
#include "htb.h"
#include "pie.h"
#include "qfq.h"
#include "netem.h"
#include "drr.h"
#include "sfb.h"
#include "sfq.h"
#include "tbf.h"
#include "teql.h"
#include <string.h>

#define TOTAL_KEYWORDS 632
#define MIN_WORD_LENGTH 8
#define MAX_WORD_LENGTH 69
#define MIN_HASH_VALUE 14
#define MAX_HASH_VALUE 3811
/* maximum key range = 3798, duplicates = 0 */

#ifdef __GNUC__
__inline
#else
#ifdef __cplusplus
inline
#endif
#endif
static unsigned int
network_network_gperf_hash (register const char *str, register size_t len)
{
  static const unsigned short asso_values[] =
    {
      3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812,
      3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812,
      3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812,
      3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812,
      3812, 3812, 3812, 3812, 3812, 3812,    0,    5, 3812,    5,
        20,   15,   25, 3812,  615, 3812, 3812, 3812, 3812, 3812,
      3812, 3812, 3812, 3812, 3812,    0,  185,  320,    0,  832,
       245,  330,  755,    5, 3812,   50,  960,  830,   30,  330,
        40,   95,  135,  570,  170,  915,  780,   45,   20, 3812,
      3812, 3812, 3812, 3812, 3812, 3812, 3812,    5,   10,   10,
       370,    0,  195,   25,  430,    0, 3812,   30,  130,  100,
         0,   70,  840,    5,    0,    5,    5,   50,  140,  555,
       755,  915,    5, 3812, 3812, 3812, 3812, 3812, 3812, 3812,
      3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812,
      3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812,
      3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812,
      3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812,
      3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812,
      3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812,
      3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812,
      3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812,
      3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812,
      3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812,
      3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812,
      3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812, 3812,
      3812, 3812, 3812, 3812, 3812, 3812
    };
  register unsigned int hval = len;

  switch (hval)
    {
      default:
        hval += asso_values[(unsigned char)str[28]];
#if (defined __cplusplus && (__cplusplus >= 201703L || (__cplusplus >= 201103L && defined __clang__ && __clang_major__ + (__clang_minor__ >= 9) > 3))) || (defined __STDC_VERSION__ && __STDC_VERSION__ >= 202000L && ((defined __GNUC__ && __GNUC__ >= 10) || (defined __clang__ && __clang_major__ >= 9)))
      [[fallthrough]];
#elif (defined __GNUC__ && __GNUC__ >= 7) || (defined __clang__ && __clang_major__ >= 10)
      __attribute__ ((__fallthrough__));
#endif
      /*FALLTHROUGH*/
      case 28:
      case 27:
      case 26:
      case 25:
      case 24:
        hval += asso_values[(unsigned char)str[23]];
#if (defined __cplusplus && (__cplusplus >= 201703L || (__cplusplus >= 201103L && defined __clang__ && __clang_major__ + (__clang_minor__ >= 9) > 3))) || (defined __STDC_VERSION__ && __STDC_VERSION__ >= 202000L && ((defined __GNUC__ && __GNUC__ >= 10) || (defined __clang__ && __clang_major__ >= 9)))
      [[fallthrough]];
#elif (defined __GNUC__ && __GNUC__ >= 7) || (defined __clang__ && __clang_major__ >= 10)
      __attribute__ ((__fallthrough__));
#endif
      /*FALLTHROUGH*/
      case 23:
      case 22:
      case 21:
      case 20:
        hval += asso_values[(unsigned char)str[19]];
#if (defined __cplusplus && (__cplusplus >= 201703L || (__cplusplus >= 201103L && defined __clang__ && __clang_major__ + (__clang_minor__ >= 9) > 3))) || (defined __STDC_VERSION__ && __STDC_VERSION__ >= 202000L && ((defined __GNUC__ && __GNUC__ >= 10) || (defined __clang__ && __clang_major__ >= 9)))
      [[fallthrough]];
#elif (defined __GNUC__ && __GNUC__ >= 7) || (defined __clang__ && __clang_major__ >= 10)
      __attribute__ ((__fallthrough__));
#endif
      /*FALLTHROUGH*/
      case 19:
      case 18:
      case 17:
      case 16:
        hval += asso_values[(unsigned char)str[15]];
#if (defined __cplusplus && (__cplusplus >= 201703L || (__cplusplus >= 201103L && defined __clang__ && __clang_major__ + (__clang_minor__ >= 9) > 3))) || (defined __STDC_VERSION__ && __STDC_VERSION__ >= 202000L && ((defined __GNUC__ && __GNUC__ >= 10) || (defined __clang__ && __clang_major__ >= 9)))
      [[fallthrough]];
#elif (defined __GNUC__ && __GNUC__ >= 7) || (defined __clang__ && __clang_major__ >= 10)
      __attribute__ ((__fallthrough__));
#endif
      /*FALLTHROUGH*/
      case 15:
      case 14:
      case 13:
      case 12:
        hval += asso_values[(unsigned char)str[11]];
#if (defined __cplusplus && (__cplusplus >= 201703L || (__cplusplus >= 201103L && defined __clang__ && __clang_major__ + (__clang_minor__ >= 9) > 3))) || (defined __STDC_VERSION__ && __STDC_VERSION__ >= 202000L && ((defined __GNUC__ && __GNUC__ >= 10) || (defined __clang__ && __clang_major__ >= 9)))
      [[fallthrough]];
#elif (defined __GNUC__ && __GNUC__ >= 7) || (defined __clang__ && __clang_major__ >= 10)
      __attribute__ ((__fallthrough__));
#endif
      /*FALLTHROUGH*/
      case 11:
      case 10:
        hval += asso_values[(unsigned char)str[9]];
#if (defined __cplusplus && (__cplusplus >= 201703L || (__cplusplus >= 201103L && defined __clang__ && __clang_major__ + (__clang_minor__ >= 9) > 3))) || (defined __STDC_VERSION__ && __STDC_VERSION__ >= 202000L && ((defined __GNUC__ && __GNUC__ >= 10) || (defined __clang__ && __clang_major__ >= 9)))
      [[fallthrough]];
#elif (defined __GNUC__ && __GNUC__ >= 7) || (defined __clang__ && __clang_major__ >= 10)
      __attribute__ ((__fallthrough__));
#endif
      /*FALLTHROUGH*/
      case 9:
      case 8:
      case 7:
        hval += asso_values[(unsigned char)str[6]];
#if (defined __cplusplus && (__cplusplus >= 201703L || (__cplusplus >= 201103L && defined __clang__ && __clang_major__ + (__clang_minor__ >= 9) > 3))) || (defined __STDC_VERSION__ && __STDC_VERSION__ >= 202000L && ((defined __GNUC__ && __GNUC__ >= 10) || (defined __clang__ && __clang_major__ >= 9)))
      [[fallthrough]];
#elif (defined __GNUC__ && __GNUC__ >= 7) || (defined __clang__ && __clang_major__ >= 10)
      __attribute__ ((__fallthrough__));
#endif
      /*FALLTHROUGH*/
      case 6:
        hval += asso_values[(unsigned char)str[5]];
#if (defined __cplusplus && (__cplusplus >= 201703L || (__cplusplus >= 201103L && defined __clang__ && __clang_major__ + (__clang_minor__ >= 9) > 3))) || (defined __STDC_VERSION__ && __STDC_VERSION__ >= 202000L && ((defined __GNUC__ && __GNUC__ >= 10) || (defined __clang__ && __clang_major__ >= 9)))
      [[fallthrough]];
#elif (defined __GNUC__ && __GNUC__ >= 7) || (defined __clang__ && __clang_major__ >= 10)
      __attribute__ ((__fallthrough__));
#endif
      /*FALLTHROUGH*/
      case 5:
      case 4:
      case 3:
      case 2:
      case 1:
        hval += asso_values[(unsigned char)str[0]];
        break;
    }
  return hval + asso_values[(unsigned char)str[len - 1]];
}

const struct ConfigPerfItem *
network_network_gperf_lookup (register const char *str, register size_t len)
{
#if (defined __GNUC__ && __GNUC__ + (__GNUC_MINOR__ >= 6) > 4) || (defined __clang__ && __clang_major__ >= 3)
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif
  static const struct ConfigPerfItem wordlist[] =
    {
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 676 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCP.IAID",                                       config_parse_iaid,                              AF_INET,                                0},
      {(char*)0}, {(char*)0},
#line 395 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.Domain",                               config_parse_dns_name,                          0,                                      offsetof(Network, dhcp_server_domain)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 189 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Address.Peer",                                    config_parse_address_section,                   ADDRESS_PEER,                           0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 458 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6SendRA.Domains",                              config_parse_radv_search_domains,               0,                                      0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 459 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6SendRA.DNSLifetimeSec",                       config_parse_sec,                               0,                                      offsetof(Network, router_dns_lifetime_usec)},
#line 283 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.IAID",                                     config_parse_iaid,                              AF_INET,                                0},
#line 190 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Address.Broadcast",                               config_parse_address_section,                   ADDRESS_BROADCAST,                      0},
#line 292 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.SendDecline",                              config_parse_bool,                              0,                                      offsetof(Network, dhcp_send_decline)},
      {(char*)0},
#line 276 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.Hostname",                                 config_parse_hostname,                          0,                                      offsetof(Network, dhcp_hostname)},
      {(char*)0},
#line 290 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.ServerPort",                               config_parse_uint16,                            0,                                      offsetof(Network, dhcp_port)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 289 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.ListenPort",                               config_parse_uint16,                            0,                                      offsetof(Network, dhcp_client_port)},
      {(char*)0}, {(char*)0},
#line 626 "../systemd/src/network/networkd-network-gperf.gperf"
      {"PIE.Handle",                                      config_parse_qdisc_handle,                      QDISC_KIND_PIE,                         0},
      {(char*)0},
#line 408 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPServerStaticLease.MACAddress",                config_parse_dhcp_static_lease_hwaddr,          0,                                      0},
      {(char*)0}, {(char*)0},
#line 194 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Address.ManageTemporaryAddress",                  config_parse_address_section,                   ADDRESS_MANAGE_TEMPORARY_ADDRESS,       0},
#line 695 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.DenyList",                           config_parse_in_addr_prefixes,                  AF_INET6,                               offsetof(Network, ndisc_deny_listed_prefix)},
#line 696 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.BlackList",                          config_parse_in_addr_prefixes,                  AF_INET6,                               offsetof(Network, ndisc_deny_listed_prefix)},
#line 345 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.UseDomains",                         config_parse_use_domains,                       0,                                      offsetof(Network, ndisc_use_domains)},
#line 337 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.UseRedirect",                        config_parse_bool,                              0,                                      offsetof(Network, ndisc_use_redirect)},
#line 625 "../systemd/src/network/networkd-network-gperf.gperf"
      {"PIE.Parent",                                      config_parse_qdisc_parent,                      QDISC_KIND_PIE,                         0},
      {(char*)0}, {(char*)0},
#line 278 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.RequestBroadcast",                         config_parse_tristate,                          0,                                      offsetof(Network, dhcp_broadcast)},
      {(char*)0},
#line 385 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.POP3",                                 config_parse_dhcp_server_emit,                  0,                                      offsetof(Network, dhcp_server_emit[SD_DHCP_LEASE_POP3])},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 405 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.PersistLeases",                        config_parse_dhcp_server_persist_leases,        0,                                      offsetof(Network, dhcp_server_persist_leases)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 361 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.Token",                              config_parse_address_generation_type,           0,                                      offsetof(Network, ndisc_tokens)},
      {(char*)0},
#line 627 "../systemd/src/network/networkd-network-gperf.gperf"
      {"PIE.PacketLimit",                                 config_parse_pie_packet_limit,                  QDISC_KIND_PIE,                         0},
      {(char*)0}, {(char*)0},
#line 264 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.UseSIP",                                   config_parse_bool,                              0,                                      offsetof(Network, dhcp_use_sip)},
#line 381 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.NTP",                                  config_parse_dhcp_server_emit,                  0,                                      offsetof(Network, dhcp_server_emit[SD_DHCP_LEASE_NTP])},
      {(char*)0},
#line 660 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.BlackList",                                config_parse_in_addr_prefixes,                  AF_INET,                                offsetof(Network, dhcp_deny_listed_ip)},
      {(char*)0},
#line 148 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.UseDomains",                              config_parse_use_domains,                       0,                                      offsetof(Network, use_domains)},
#line 127 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.MACsec",                                  config_parse_stacked_netdev,                    NETDEV_KIND_MACSEC,                     offsetof(Network, stacked_netdev_names)},
      {(char*)0},
#line 353 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.QuickAck",                           config_parse_bool,                              0,                                      offsetof(Network, ndisc_quickack)},
      {(char*)0}, {(char*)0},
#line 117 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.Description",                             config_parse_string,                            0,                                      offsetof(Network, description)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 271 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.QuickAck",                                 config_parse_bool,                              0,                                      offsetof(Network, dhcp_quickack)},
      {(char*)0},
#line 554 "../systemd/src/network/networkd-network-gperf.gperf"
      {"PFIFO.Parent",                                    config_parse_qdisc_parent,                      QDISC_KIND_PFIFO,                       0},
#line 286 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.RouteMetric",                              config_parse_dhcp_route_metric,                 AF_INET,                                0},
#line 193 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Address.HomeAddress",                             config_parse_address_section,                   ADDRESS_HOME_ADDRESS,                   0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 351 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.RouteTable",                         config_parse_dhcp_or_ra_route_table,            NETWORK_CONFIG_SOURCE_NDISC,            0},
      {(char*)0},
#line 697 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.UseICMP6RateLimit",                  config_parse_warn_compat,                       DISABLED_LEGACY,                        0},
#line 360 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.RouteDenyList",                      config_parse_in_addr_prefixes,                  AF_INET6,                               offsetof(Network, ndisc_deny_listed_route_prefix)},
      {(char*)0},
#line 288 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.UseTimezone",                              config_parse_bool,                              0,                                      offsetof(Network, dhcp_use_timezone)},
      {(char*)0},
#line 685 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.UseDomainName",                            config_parse_use_domains,                       0,                                      offsetof(Network, dhcp_use_domains)},
      {(char*)0},
#line 268 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.UseDomains",                               config_parse_use_domains,                       0,                                      offsetof(Network, dhcp_use_domains)},
#line 267 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.UseHostname",                              config_parse_bool,                              0,                                      offsetof(Network, dhcp_use_hostname)},
#line 200 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Address.RouteMetric",                             config_parse_address_section,                   ADDRESS_ROUTE_METRIC,                   0},
      {(char*)0},
#line 269 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.UseRoutes",                                config_parse_bool,                              0,                                      offsetof(Network, dhcp_use_routes)},
      {(char*)0},
#line 132 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.VXLAN",                                   config_parse_stacked_netdev,                    NETDEV_KIND_VXLAN,                      offsetof(Network, stacked_netdev_names)},
#line 352 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.RouteMetric",                        config_parse_ndisc_route_metric,                0,                                      0},
#line 160 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.IPMasquerade",                            config_parse_ip_masquerade,                     0,                                      offsetof(Network, ip_masquerade)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 556 "../systemd/src/network/networkd-network-gperf.gperf"
      {"PFIFO.PacketLimit",                               config_parse_pfifo_size,                        QDISC_KIND_PFIFO,                       0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 618 "../systemd/src/network/networkd-network-gperf.gperf"
      {"NetworkEmulator.Parent",                          config_parse_qdisc_parent,                      QDISC_KIND_NETEM,                       0},
      {(char*)0},
#line 622 "../systemd/src/network/networkd-network-gperf.gperf"
      {"NetworkEmulator.LossRate",                        config_parse_netem_rate,                        QDISC_KIND_NETEM,                       0},
      {(char*)0},
#line 197 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Address.AutoJoin",                                config_parse_address_section,                   ADDRESS_AUTO_JOIN,                      0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 391 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.Router",                               config_parse_in_addr_non_null,                  AF_INET,                                offsetof(Network, dhcp_server_router)},
      {(char*)0}, {(char*)0},
#line 147 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.Domains",                                 config_parse_domains,                           0,                                      0},
      {(char*)0},
#line 515 "../systemd/src/network/networkd-network-gperf.gperf"
      {"QDisc.Parent",                                    config_parse_qdisc_parent,                      _QDISC_KIND_INVALID,                    0},
#line 191 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Address.Label",                                   config_parse_address_section,                   ADDRESS_LABEL,                          0},
      {(char*)0}, {(char*)0},
#line 140 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.IPv4LLStartAddress",                      config_parse_ipv4ll_address,                    0,                                      offsetof(Network, ipv4ll_start_address)},
      {(char*)0},
#line 263 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.RoutesToNTP",                              config_parse_bool,                              0,                                      offsetof(Network, dhcp_routes_to_ntp)},
#line 620 "../systemd/src/network/networkd-network-gperf.gperf"
      {"NetworkEmulator.DelaySec",                        config_parse_netem_delay,                       QDISC_KIND_NETEM,                       0},
#line 621 "../systemd/src/network/networkd-network-gperf.gperf"
      {"NetworkEmulator.DelayJitterSec",                  config_parse_netem_delay,                       QDISC_KIND_NETEM,                       0},
      {(char*)0},
#line 453 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6SendRA.RouterPreference",                     config_parse_router_preference,                 0,                                      offsetof(Network, router_preference)},
      {(char*)0}, {(char*)0},
#line 171 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.IPv4RouteLocalnet",                       config_parse_tristate,                          0,                                      offsetof(Network, ipv4_route_localnet)},
      {(char*)0},
#line 126 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.L2TP",                                    config_parse_warn_compat,                       DISABLED_LEGACY,                        0},
#line 303 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.Use6RD",                                   config_parse_bool,                              0,                                      offsetof(Network, dhcp_use_6rd)},
      {(char*)0}, {(char*)0},
#line 672 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCP.RequestBroadcast",                           config_parse_tristate,                          0,                                      offsetof(Network, dhcp_broadcast)},
#line 624 "../systemd/src/network/networkd-network-gperf.gperf"
      {"NetworkEmulator.PacketLimit",                     config_parse_netem_packet_limit,                QDISC_KIND_NETEM,                       0},
      {(char*)0}, {(char*)0},
#line 306 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.NetLabel",                                 config_parse_string,                            CONFIG_PARSE_STRING_SAFE,               offsetof(Network, dhcp_netlabel)},
      {(char*)0},
#line 364 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPRelay.AgentAddress",                          config_parse_in_addr_non_null,                  AF_INET,                                offsetof(Network, dhcp_relay_agent_address_in_addr)},
#line 291 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.SendRelease",                              config_parse_bool,                              0,                                      offsetof(Network, dhcp_send_release)},
#line 344 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.UseDNR",                             config_parse_tristate,                          0,                                      offsetof(Network, ndisc_use_dnr)},
      {(char*)0},
#line 362 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.NetLabel",                           config_parse_string,                            CONFIG_PARSE_STRING_SAFE,               offsetof(Network, ndisc_netlabel)},
      {(char*)0}, {(char*)0},
#line 450 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6SendRA.RetransmitSec",                        config_parse_router_uint32_msec_usec,           0,                                      offsetof(Network, router_retransmit_usec)},
      {(char*)0},
#line 472 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6RoutePrefix.Route",                           config_parse_route_prefix,                      0,                                      0},
      {(char*)0},
#line 285 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.DUIDRawData",                              config_parse_network_duid_rawdata,              0,                                      0},
#line 393 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.Timezone",                             config_parse_timezone,                          0,                                      offsetof(Network, dhcp_server_timezone)},
#line 184 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.IgnoreCarrierLoss",                       config_parse_ignore_carrier_loss,               0,                                      0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 348 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.UseReachableTime",                   config_parse_bool,                              0,                                      offsetof(Network, ndisc_use_reachable_time)},
      {(char*)0}, {(char*)0},
#line 473 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6RoutePrefix.LifetimeSec",                     config_parse_route_prefix_lifetime,             0,                                      0},
#line 260 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.UseDNR",                                   config_parse_tristate,                          0,                                      offsetof(Network, dhcp_use_dnr)},
      {(char*)0}, {(char*)0},
#line 410 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Bridge.Cost",                                     config_parse_uint32,                            0,                                      offsetof(Network, cost)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 307 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.NFTSet",                                   config_parse_nft_set,                           NFT_SET_PARSE_NETWORK,                  offsetof(Network, dhcp_nft_set_context)},
#line 141 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.IPv4LLRoute",                             config_parse_bool,                              0,                                      offsetof(Network, ipv4ll_route)},
#line 284 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.DUIDType",                                 config_parse_network_duid_type,                 0,                                      0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 173 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.ActiveSlave",                             config_parse_bool,                              0,                                      offsetof(Network, active_slave)},
#line 409 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPServerStaticLease.Hostname",                  config_parse_dhcp_static_lease_hostname,        0,                                      0},
      {(char*)0},
#line 287 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.RouteTable",                               config_parse_dhcp_or_ra_route_table,            NETWORK_CONFIG_SOURCE_DHCP4,            0},
      {(char*)0},
#line 363 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.NFTSet",                             config_parse_nft_set,                           NFT_SET_PARSE_NETWORK,                  offsetof(Network, ndisc_nft_set_context)},
#line 680 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCP.RouteTable",                                 config_parse_dhcp_or_ra_route_table,            NETWORK_CONFIG_SOURCE_DHCP4,            0},
      {(char*)0},
#line 228 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Route.Destination",                               config_parse_route_section,                     ROUTE_DESTINATION,                      0},
#line 142 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.DefaultRouteOnDevice",                    config_parse_bool,                              0,                                      offsetof(Network, default_route_on_device)},
      {(char*)0},
#line 420 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Bridge.Learning",                                 config_parse_tristate,                          0,                                      offsetof(Network, learning)},
      {(char*)0}, {(char*)0},
#line 150 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.DNSDefaultRoute",                         config_parse_tristate,                          0,                                      offsetof(Network, dns_default_route)},
#line 349 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.UseRetransmissionTime",              config_parse_bool,                              0,                                      offsetof(Network, ndisc_use_retransmission_time)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 412 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Bridge.HairPin",                                  config_parse_tristate,                          0,                                      offsetof(Network, hairpin)},
      {(char*)0},
#line 679 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCP.RouteMetric",                                config_parse_dhcp_route_metric,                 AF_UNSPEC,                              0},
      {(char*)0},
#line 258 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.ClientIdentifier",                         config_parse_dhcp_client_identifier,            0,                                      offsetof(Network, dhcp_client_identifier)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 517 "../systemd/src/network/networkd-network-gperf.gperf"
      {"BFIFO.Parent",                                    config_parse_qdisc_parent,                      QDISC_KIND_BFIFO,                       0},
#line 262 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.UseNTP",                                   config_parse_tristate,                          0,                                      offsetof(Network, dhcp_use_ntp)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 130 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.Tunnel",                                  config_parse_stacked_netdev,                    _NETDEV_KIND_TUNNEL,                    offsetof(Network, stacked_netdev_names)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 376 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.DefaultLeaseTimeSec",                  config_parse_sec,                               0,                                      offsetof(Network, dhcp_server_default_lease_time_usec)},
#line 144 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.EmitLLDP",                                config_parse_lldp_multicast_mode,               0,                                      offsetof(Network, lldp_multicast_mode)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 504 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPoIB.IgnoreUserspaceMulticastGroups",            config_parse_tristate,                          0,                                      offsetof(Network, ipoib_umcast)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 623 "../systemd/src/network/networkd-network-gperf.gperf"
      {"NetworkEmulator.DuplicateRate",                   config_parse_netem_rate,                        QDISC_KIND_NETEM,                       0},
      {(char*)0},
#line 156 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.NTP",                                     config_parse_ntp,                               0,                                      offsetof(Network, ntp)},
      {(char*)0}, {(char*)0},
#line 247 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Route.QuickAck",                                  config_parse_route_section,                     ROUTE_METRIC_QUICKACK,                  0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 299 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.RouteMTUBytes",                            config_parse_mtu,                               AF_INET,                                offsetof(Network, dhcp_route_mtu)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 195 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Address.PrefixRoute",                             config_parse_address_section,                   ADDRESS_PREFIX_ROUTE,                   0 /* deprecated */},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 123 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.IPoIB",                                   config_parse_stacked_netdev,                    NETDEV_KIND_IPOIB,                      offsetof(Network, stacked_netdev_names)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 277 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.Label",                                    config_parse_dhcp_label,                        0,                                      offsetof(Network, dhcp_label)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 558 "../systemd/src/network/networkd-network-gperf.gperf"
      {"PFIFOFast.Handle",                                config_parse_qdisc_handle,                      QDISC_KIND_PFIFO_FAST,                  0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 238 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Route.Type",                                      config_parse_route_section,                     ROUTE_TYPE,                             0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 557 "../systemd/src/network/networkd-network-gperf.gperf"
      {"PFIFOFast.Parent",                                config_parse_qdisc_parent,                      QDISC_KIND_PFIFO_FAST,                  0},
#line 342 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.UsePREF64",                          config_parse_bool,                              0,                                      offsetof(Network, ndisc_use_pref64)},
#line 265 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.UseCaptivePortal",                         config_parse_bool,                              0,                                      offsetof(Network, dhcp_use_captive_portal)},
#line 125 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.IPVTAP",                                  config_parse_stacked_netdev,                    NETDEV_KIND_IPVTAP,                     offsetof(Network, stacked_netdev_names)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 237 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Route.Protocol",                                  config_parse_route_section,                     ROUTE_PROTOCOL,                         0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 569 "../systemd/src/network/networkd-network-gperf.gperf"
      {"FairQueueing.Handle",                             config_parse_qdisc_handle,                      QDISC_KIND_FQ,                          0},
#line 502 "../systemd/src/network/networkd-network-gperf.gperf"
      {"CAN.Termination",                                 config_parse_can_termination,                   0,                                      0},
#line 478 "../systemd/src/network/networkd-network-gperf.gperf"
      {"CAN.BitRate",                                     config_parse_can_bitrate,                       0,                                      offsetof(Network, can_bitrate)},
      {(char*)0}, {(char*)0},
#line 568 "../systemd/src/network/networkd-network-gperf.gperf"
      {"FairQueueing.Parent",                             config_parse_qdisc_parent,                      QDISC_KIND_FQ,                          0},
      {(char*)0}, {(char*)0},
#line 424 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Bridge.MulticastRouter",                          config_parse_multicast_router,                  0,                                      offsetof(Network, multicast_router)},
#line 170 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.IPv4AcceptLocal",                         config_parse_tristate,                          0,                                      offsetof(Network, ipv4_accept_local)},
#line 535 "../systemd/src/network/networkd-network-gperf.gperf"
      {"CAKE.AckFilter",                                  config_parse_cake_ack_filter,                   QDISC_KIND_CAKE,                        0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 673 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCP.CriticalConnection",                         config_parse_tristate,                          0,                                      offsetof(Network, dhcp_critical)},
      {(char*)0},
#line 418 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Bridge.MulticastToUnicast",                       config_parse_tristate,                          0,                                      offsetof(Network, multicast_to_unicast)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 575 "../systemd/src/network/networkd-network-gperf.gperf"
      {"FairQueueing.Buckets",                            config_parse_fq_u32,                            QDISC_KIND_FQ,                          0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 354 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.UseCaptivePortal",                   config_parse_bool,                              0,                                      offsetof(Network, ndisc_use_captive_portal)},
      {(char*)0},
#line 183 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.ConfigureWithoutCarrier",                 config_parse_bool,                              0,                                      offsetof(Network, configure_without_carrier)},
      {(char*)0},
#line 495 "../systemd/src/network/networkd-network-gperf.gperf"
      {"CAN.TripleSampling",                              config_parse_can_control_mode,                  CAN_CTRLMODE_3_SAMPLES,                 0},
      {(char*)0}, {(char*)0},
#line 282 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.UserClass",                                config_parse_dhcp4_user_class,                  0,                                      offsetof(Network, dhcp_user_class)},
      {(char*)0}, {(char*)0},
#line 577 "../systemd/src/network/networkd-network-gperf.gperf"
      {"FairQueueing.Pacing",                             config_parse_fq_bool,                           QDISC_KIND_FQ,                          0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 520 "../systemd/src/network/networkd-network-gperf.gperf"
      {"CAKE.Parent",                                     config_parse_qdisc_parent,                      QDISC_KIND_CAKE,                        0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 474 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6RoutePrefix.Preference",                      config_parse_route_prefix_preference,           0,                                      0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 400 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.BindToInterface",                      config_parse_warn_compat,                       DISABLED_LEGACY,                        0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 396 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.PoolOffset",                           config_parse_uint32,                            0,                                      offsetof(Network, dhcp_server_pool_offset)},
#line 530 "../systemd/src/network/networkd-network-gperf.gperf"
      {"CAKE.PriorityQueueingPreset",                     config_parse_cake_priority_queueing_preset,     QDISC_KIND_CAKE,                        0},
      {(char*)0}, {(char*)0},
#line 188 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Address.Address",                                 config_parse_address_section,                   ADDRESS_ADDRESS,                        0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 698 "../systemd/src/network/networkd-network-gperf.gperf"
      {"TrafficControlQueueingDiscipline.Parent",                        config_parse_qdisc_parent,       _QDISC_KIND_INVALID,                    0},
      {(char*)0},
#line 496 "../systemd/src/network/networkd-network-gperf.gperf"
      {"CAN.OneShot",                                     config_parse_can_control_mode,                  CAN_CTRLMODE_ONE_SHOT,                  0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 701 "../systemd/src/network/networkd-network-gperf.gperf"
      {"TrafficControlQueueingDiscipline.NetworkEmulatorLossRate",       config_parse_netem_rate,         0,                                      0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 702 "../systemd/src/network/networkd-network-gperf.gperf"
      {"TrafficControlQueueingDiscipline.NetworkEmulatorDuplicateRate",  config_parse_netem_rate,         0,                                      0},
      {(char*)0}, {(char*)0},
#line 703 "../systemd/src/network/networkd-network-gperf.gperf"
      {"TrafficControlQueueingDiscipline.NetworkEmulatorPacketLimit",    config_parse_netem_packet_limit, 0,                                      0},
      {(char*)0},
#line 699 "../systemd/src/network/networkd-network-gperf.gperf"
      {"TrafficControlQueueingDiscipline.NetworkEmulatorDelaySec",       config_parse_netem_delay,        0,                                      0},
      {(char*)0}, {(char*)0},
#line 407 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPServerStaticLease.Address",                   config_parse_dhcp_static_lease_address,         0,                                      0},
      {(char*)0},
#line 257 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.RequestAddress",                           config_parse_in_addr_non_null,                  AF_INET,                                offsetof(Network, dhcp_request_address)},
#line 700 "../systemd/src/network/networkd-network-gperf.gperf"
      {"TrafficControlQueueingDiscipline.NetworkEmulatorDelayJitterSec", config_parse_netem_delay,        0,                                      0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 452 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6SendRA.OtherInformation",                     config_parse_bool,                              0,                                      offsetof(Network, router_other_information)},
#line 250 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Route.TTLPropagate",                              config_parse_warn_compat,                       DISABLED_LEGACY,                        0},
#line 179 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.IPv4ReversePathFilter",                   config_parse_ip_reverse_path_filter,            0,                                      offsetof(Network, ipv4_rp_filter)},
#line 686 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.CriticalConnection",                       config_parse_tristate,                          0,                                      offsetof(Network, dhcp_critical)},
      {(char*)0},
#line 297 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.SendOption",                               config_parse_dhcp_option_tlv,                   0,                                      offsetof(Network, dhcp_extra_options)},
      {(char*)0},
#line 121 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.Bridge",                                  config_parse_ifname,                            0,                                      offsetof(Network, bridge_name)},
      {(char*)0},
#line 233 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Route.Table",                                     config_parse_route_section,                     ROUTE_TABLE,                            0},
#line 275 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.BOOTP",                                    config_parse_bool,                              0,                                      offsetof(Network, dhcp_use_bootp)},
      {(char*)0},
#line 182 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.BindCarrier",                             config_parse_strv,                              0,                                      offsetof(Network, bind_carrier)},
#line 145 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.Address",                                 config_parse_address_section,                   ADDRESS_ADDRESS,                        0},
#line 122 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.VRF",                                     config_parse_ifname,                            0,                                      offsetof(Network, vrf_name)},
      {(char*)0},
#line 403 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.BootFilename",                         config_parse_string,                            CONFIG_PARSE_STRING_SAFE_AND_ASCII,     offsetof(Network, dhcp_server_boot_filename)},
      {(char*)0},
#line 572 "../systemd/src/network/networkd-network-gperf.gperf"
      {"FairQueueing.QuantumBytes",                       config_parse_fq_size,                           QDISC_KIND_FQ,                          0},
      {(char*)0},
#line 223 "../systemd/src/network/networkd-network-gperf.gperf"
      {"RoutingPolicyRule.User",                          config_parse_routing_policy_rule,               ROUTING_POLICY_RULE_UID_RANGE,          0},
#line 211 "../systemd/src/network/networkd-network-gperf.gperf"
      {"RoutingPolicyRule.Table",                         config_parse_routing_policy_rule,               ROUTING_POLICY_RULE_TABLE,              0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 595 "../systemd/src/network/networkd-network-gperf.gperf"
      {"GenericRandomEarlyDetection.DefaultVirtualQueue", config_parse_gred_u32,                          QDISC_KIND_GRED,                        0},
#line 220 "../systemd/src/network/networkd-network-gperf.gperf"
      {"RoutingPolicyRule.InvertRule",                    config_parse_routing_policy_rule,               ROUTING_POLICY_RULE_INVERT,             0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 133 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.Xfrm",                                    config_parse_stacked_netdev,                    NETDEV_KIND_XFRM,                       offsetof(Network, stacked_netdev_names)},
#line 219 "../systemd/src/network/networkd-network-gperf.gperf"
      {"RoutingPolicyRule.DestinationPort",               config_parse_routing_policy_rule,               ROUTING_POLICY_RULE_DPORT,              0},
#line 563 "../systemd/src/network/networkd-network-gperf.gperf"
      {"QuickFairQueueing.Handle",                        config_parse_qdisc_handle,                      QDISC_KIND_QFQ,                         0},
#line 215 "../systemd/src/network/networkd-network-gperf.gperf"
      {"RoutingPolicyRule.IncomingInterface",             config_parse_routing_policy_rule,               ROUTING_POLICY_RULE_IIF,                0},
      {(char*)0}, {(char*)0},
#line 448 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6SendRA.RouterLifetimeSec",                    config_parse_router_lifetime,                   0,                                      offsetof(Network, router_lifetime_usec)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 431 "../systemd/src/network/networkd-network-gperf.gperf"
      {"BridgeFDB.VNI",                                   config_parse_fdb_vxlan_vni,                     0,                                      0},
#line 562 "../systemd/src/network/networkd-network-gperf.gperf"
      {"QuickFairQueueing.Parent",                        config_parse_qdisc_parent,                      QDISC_KIND_QFQ,                         0},
#line 485 "../systemd/src/network/networkd-network-gperf.gperf"
      {"CAN.DataBitRate",                                 config_parse_can_bitrate,                       0,                                      offsetof(Network, can_data_bitrate)},
#line 661 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCP.ClientIdentifier",                           config_parse_dhcp_client_identifier,            0,                                      offsetof(Network, dhcp_client_identifier)},
      {(char*)0}, {(char*)0},
#line 499 "../systemd/src/network/networkd-network-gperf.gperf"
      {"CAN.PresumeACK",                                  config_parse_can_control_mode,                  CAN_CTRLMODE_PRESUME_ACK,               0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 617 "../systemd/src/network/networkd-network-gperf.gperf"
      {"BandMultiQueueing.Handle",                        config_parse_qdisc_handle,                      QDISC_KIND_MULTIQ,                      0},
      {(char*)0},
#line 497 "../systemd/src/network/networkd-network-gperf.gperf"
      {"CAN.BusErrorReporting",                           config_parse_can_control_mode,                  CAN_CTRLMODE_BERR_REPORTING,            0},
#line 196 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Address.AddPrefixRoute",                          config_parse_address_section,                   ADDRESS_ADD_PREFIX_ROUTE,               0},
      {(char*)0},
#line 592 "../systemd/src/network/networkd-network-gperf.gperf"
      {"GenericRandomEarlyDetection.Parent",              config_parse_qdisc_parent,                      QDISC_KIND_GRED,                        0},
#line 212 "../systemd/src/network/networkd-network-gperf.gperf"
      {"RoutingPolicyRule.FirewallMark",                  config_parse_routing_policy_rule,               ROUTING_POLICY_RULE_FWMARK,             0},
      {(char*)0}, {(char*)0},
#line 279 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.VendorClassIdentifier",                    config_parse_string,                            CONFIG_PARSE_STRING_SAFE,               offsetof(Network, dhcp_vendor_class_identifier)},
#line 616 "../systemd/src/network/networkd-network-gperf.gperf"
      {"BandMultiQueueing.Parent",                        config_parse_qdisc_parent,                      QDISC_KIND_MULTIQ,                      0},
      {(char*)0}, {(char*)0},
#line 427 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Bridge.VLANTunnel",                               config_parse_tristate,                          0,                                      offsetof(Network, bridge_vlan_tunnel)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 205 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Neighbor.Address",                                config_parse_neighbor_section,                  NEIGHBOR_DESTINATION_ADDRESS,           0},
#line 619 "../systemd/src/network/networkd-network-gperf.gperf"
      {"NetworkEmulator.Handle",                          config_parse_qdisc_handle,                      QDISC_KIND_NETEM,                       0},
      {(char*)0},
#line 586 "../systemd/src/network/networkd-network-gperf.gperf"
      {"FairQueueingControlledDelay.IntervalSec",         config_parse_fq_codel_usec,                     QDISC_KIND_FQ_CODEL,                    0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 479 "../systemd/src/network/networkd-network-gperf.gperf"
      {"CAN.SamplePoint",                                 config_parse_permille,                          0,                                      offsetof(Network, can_sample_point)},
      {(char*)0},
#line 571 "../systemd/src/network/networkd-network-gperf.gperf"
      {"FairQueueing.FlowLimit",                          config_parse_fq_u32,                            QDISC_KIND_FQ,                          0},
      {(char*)0},
#line 366 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPRelay.CircuitId",                             config_parse_dhcp_option,                       /* check_length= */ true,               offsetof(Network, dhcp_relay_circuit_id)},
#line 216 "../systemd/src/network/networkd-network-gperf.gperf"
      {"RoutingPolicyRule.OutgoingInterface",             config_parse_routing_policy_rule,               ROUTING_POLICY_RULE_OIF,                0},
#line 430 "../systemd/src/network/networkd-network-gperf.gperf"
      {"BridgeFDB.Destination",                           config_parse_fdb_destination,                   0,                                      0},
#line 137 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.LinkLocalAddressing",                     config_parse_link_local_address_family,         0,                                      offsetof(Network, link_local)},
      {(char*)0},
#line 564 "../systemd/src/network/networkd-network-gperf.gperf"
      {"QuickFairQueueingClass.Parent",                   config_parse_tclass_parent,                     TCLASS_KIND_QFQ,                        0},
#line 192 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Address.PreferredLifetime",                       config_parse_address_section,                   ADDRESS_PREFERRED_LIFETIME,             0},
      {(char*)0}, {(char*)0},
#line 529 "../systemd/src/network/networkd-network-gperf.gperf"
      {"CAKE.NAT",                                        config_parse_cake_tristate,                     QDISC_KIND_CAKE,                        0},
#line 566 "../systemd/src/network/networkd-network-gperf.gperf"
      {"QuickFairQueueingClass.Weight",                   config_parse_qfq_weight,                        TCLASS_KIND_QFQ,                        0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 218 "../systemd/src/network/networkd-network-gperf.gperf"
      {"RoutingPolicyRule.SourcePort",                    config_parse_routing_policy_rule,               ROUTING_POLICY_RULE_SPORT,              0},
#line 579 "../systemd/src/network/networkd-network-gperf.gperf"
      {"FairQueueingControlledDelay.Parent",              config_parse_qdisc_parent,                      QDISC_KIND_FQ_CODEL,                    0},
      {(char*)0}, {(char*)0},
#line 493 "../systemd/src/network/networkd-network-gperf.gperf"
      {"CAN.Loopback",                                    config_parse_can_control_mode,                  CAN_CTRLMODE_LOOPBACK,                  0},
      {(char*)0},
#line 581 "../systemd/src/network/networkd-network-gperf.gperf"
      {"FairQueueingControlledDelay.PacketLimit",         config_parse_fq_codel_u32,                      QDISC_KIND_FQ_CODEL,                    0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 365 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPRelay.GatewayAddress",                        config_parse_in_addr_non_null,                  AF_INET,                                offsetof(Network, dhcp_relay_gateway_address)},
#line 704 "../systemd/src/network/networkd-network-gperf.gperf"
      {"FairQueueing.Quantum",                            config_parse_fq_size,                           QDISC_KIND_FQ,                          0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 213 "../systemd/src/network/networkd-network-gperf.gperf"
      {"RoutingPolicyRule.From",                          config_parse_routing_policy_rule,               ROUTING_POLICY_RULE_FROM,               0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 157 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.IPForward",                               config_parse_ip_forward_deprecated,             0,                                      0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 523 "../systemd/src/network/networkd-network-gperf.gperf"
      {"CAKE.AutoRateIngress",                            config_parse_cake_tristate,                     QDISC_KIND_CAKE,                        0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 705 "../systemd/src/network/networkd-network-gperf.gperf"
      {"FairQueueing.InitialQuantum",                     config_parse_fq_size,                           QDISC_KIND_FQ,                          0},
#line 425 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Bridge.Locked",                                   config_parse_tristate,                          0,                                      offsetof(Network, bridge_locked)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 379 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.DNS",                                  config_parse_dhcp_server_emit,                  0,                                      offsetof(Network, dhcp_server_emit[SD_DHCP_LEASE_DNS])},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 456 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6SendRA.DNS",                                  config_parse_radv_dns,                          0,                                      0},
#line 214 "../systemd/src/network/networkd-network-gperf.gperf"
      {"RoutingPolicyRule.To",                            config_parse_routing_policy_rule,               ROUTING_POLICY_RULE_TO,                 0},
      {(char*)0},
#line 210 "../systemd/src/network/networkd-network-gperf.gperf"
      {"RoutingPolicyRule.GoTo",                          config_parse_routing_policy_rule,               ROUTING_POLICY_RULE_GOTO,               0},
      {(char*)0},
#line 646 "../systemd/src/network/networkd-network-gperf.gperf"
      {"/* backwards compatibility: do not add new entries to this section */"},
#line 584 "../systemd/src/network/networkd-network-gperf.gperf"
      {"FairQueueingControlledDelay.QuantumBytes",        config_parse_fq_codel_size,                     QDISC_KIND_FQ_CODEL,                    0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 426 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Bridge.MACAuthenticationBypass",                  config_parse_tristate,                          0,                                      offsetof(Network, bridge_mac_authentication_bypass)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 683 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCP.RapidCommit",                                config_parse_bool,                              0,                                      offsetof(Network, dhcp6_use_rapid_commit)},
#line 449 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6SendRA.ReachableTimeSec",                     config_parse_router_uint32_msec_usec,           0,                                      offsetof(Network, router_reachable_usec)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 198 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Address.DuplicateAddressDetection",               config_parse_address_section,                   ADDRESS_DAD,                            0},
      {(char*)0},
#line 295 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.IPServiceType",                            config_parse_dhcp_ip_service_type,              0,                                      offsetof(Network, dhcp_ip_service_type)},
      {(char*)0}, {(char*)0},
#line 357 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.PrefixAllowList",                    config_parse_in_addr_prefixes,                  AF_INET6,                               offsetof(Network, ndisc_allow_listed_prefix)},
#line 343 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.UseDNS",                             config_parse_tristate,                          0,                                      offsetof(Network, ndisc_use_dns)},
      {(char*)0}, {(char*)0},
#line 221 "../systemd/src/network/networkd-network-gperf.gperf"
      {"RoutingPolicyRule.L3MasterDevice",                config_parse_routing_policy_rule,               ROUTING_POLICY_RULE_L3MDEV,             0},
      {(char*)0},
#line 383 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.SIP",                                  config_parse_dhcp_server_emit,                  0,                                      offsetof(Network, dhcp_server_emit[SD_DHCP_LEASE_SIP])},
#line 387 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.SMTP",                                 config_parse_dhcp_server_emit,                  0,                                      offsetof(Network, dhcp_server_emit[SD_DHCP_LEASE_SMTP])},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 397 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.PoolSize",                             config_parse_uint32,                            0,                                      offsetof(Network, dhcp_server_pool_size)},
      {(char*)0},
#line 329 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.IAID",                                     config_parse_iaid,                              AF_INET6,                               0},
#line 404 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.RapidCommit",                          config_parse_bool,                              0,                                      offsetof(Network, dhcp_server_rapid_commit)},
#line 217 "../systemd/src/network/networkd-network-gperf.gperf"
      {"RoutingPolicyRule.IPProtocol",                    config_parse_routing_policy_rule,               ROUTING_POLICY_RULE_IP_PROTOCOL,        0},
      {(char*)0},
#line 320 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.Hostname",                                 config_parse_hostname,                          0,                                      offsetof(Network, dhcp6_hostname)},
      {(char*)0}, {(char*)0},
#line 259 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.UseDNS",                                   config_parse_tristate,                          0,                                      offsetof(Network, dhcp_use_dns)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 413 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Bridge.Isolated",                                 config_parse_tristate,                          0,                                      offsetof(Network, isolated)},
#line 534 "../systemd/src/network/networkd-network-gperf.gperf"
      {"CAKE.RTTSec",                                     config_parse_cake_rtt,                          QDISC_KIND_CAKE,                        0},
      {(char*)0}, {(char*)0},
#line 235 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Route.GatewayOnlink",                             config_parse_route_section,                     ROUTE_GATEWAY_ONLINK,                   0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 615 "../systemd/src/network/networkd-network-gperf.gperf"
      {"ClassfulMultiQueueing.Handle",                    config_parse_qdisc_handle,                      QDISC_KIND_MQ,                          0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 614 "../systemd/src/network/networkd-network-gperf.gperf"
      {"ClassfulMultiQueueing.Parent",                    config_parse_qdisc_parent,                      QDISC_KIND_MQ,                          0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 261 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.RoutesToDNS",                              config_parse_bool,                              0,                                      offsetof(Network, dhcp_routes_to_dns)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 355 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.RouterAllowList",                    config_parse_in_addr_prefixes,                  AF_INET6,                               offsetof(Network, ndisc_allow_listed_router)},
      {(char*)0}, {(char*)0},
#line 149 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.DNS",                                     config_parse_dns,                               0,                                      0},
#line 585 "../systemd/src/network/networkd-network-gperf.gperf"
      {"FairQueueingControlledDelay.TargetSec",           config_parse_fq_codel_usec,                     QDISC_KIND_FQ_CODEL,                    0},
#line 316 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.UseSIP",                                   config_parse_bool,                              0,                                      offsetof(Network, dhcp6_use_sip)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 636 "../systemd/src/network/networkd-network-gperf.gperf"
      {"TokenBucketFilter.Rate",                          config_parse_tbf_rate,                          QDISC_KIND_TBF,                         0},
      {(char*)0},
#line 635 "../systemd/src/network/networkd-network-gperf.gperf"
      {"TokenBucketFilter.Handle",                        config_parse_qdisc_handle,                      QDISC_KIND_TBF,                         0},
      {(char*)0},
#line 641 "../systemd/src/network/networkd-network-gperf.gperf"
      {"TokenBucketFilter.PeakRate",                      config_parse_tbf_rate,                          QDISC_KIND_TBF,                         0},
      {(char*)0},
#line 632 "../systemd/src/network/networkd-network-gperf.gperf"
      {"StochasticFairnessQueueing.Handle",               config_parse_qdisc_handle,                      QDISC_KIND_SFQ,                         0},
      {(char*)0},
#line 707 "../systemd/src/network/networkd-network-gperf.gperf"
      {"FairQueueingControlledDelay.Quantum",             config_parse_fq_codel_size,                     QDISC_KIND_FQ_CODEL,                    0},
      {(char*)0},
#line 165 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.IPv4DuplicateAddressDetectionTimeoutSec", config_parse_sec,                               0,                                      offsetof(Network, ipv4_dad_timeout_usec)},
#line 631 "../systemd/src/network/networkd-network-gperf.gperf"
      {"StochasticFairnessQueueing.Parent",               config_parse_qdisc_parent,                      QDISC_KIND_SFQ,                         0},
#line 634 "../systemd/src/network/networkd-network-gperf.gperf"
      {"TokenBucketFilter.Parent",                        config_parse_qdisc_parent,                      QDISC_KIND_TBF,                         0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 687 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.RouteMetric",                              config_parse_ndisc_route_metric,                AF_INET6,                               0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 633 "../systemd/src/network/networkd-network-gperf.gperf"
      {"StochasticFairnessQueueing.PerturbPeriodSec",     config_parse_sfq_perturb_period,                QDISC_KIND_SFQ,                         0},
#line 155 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.DNSSECNegativeTrustAnchors",              config_parse_dnssec_negative_trust_anchors,     0,                                      offsetof(Network, dnssec_negative_trust_anchors)},
#line 350 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.DHCPv6Client",                       config_parse_ndisc_start_dhcp6_client,          0,                                      offsetof(Network, ndisc_start_dhcp6_client)},
      {(char*)0},
#line 433 "../systemd/src/network/networkd-network-gperf.gperf"
      {"BridgeFDB.OutgoingInterface",                     config_parse_fdb_interface,                     0,                                      0},
#line 642 "../systemd/src/network/networkd-network-gperf.gperf"
      {"TokenBucketFilter.LatencySec",                    config_parse_tbf_latency,                       QDISC_KIND_TBF,                         0},
      {(char*)0}, {(char*)0},
#line 327 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.WithoutRA",                                config_parse_dhcp6_client_start_mode,           0,                                      offsetof(Network, dhcp6_client_start_mode)},
#line 314 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.UseDomains",                               config_parse_use_domains,                       0,                                      offsetof(Network, dhcp6_use_domains)},
#line 313 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.UseHostname",                              config_parse_bool,                              0,                                      offsetof(Network, dhcp6_use_hostname)},
#line 416 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Bridge.UnicastFlood",                             config_parse_tristate,                          0,                                      offsetof(Network, unicast_flood)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 323 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.VendorClass",                              config_parse_dhcp6_user_or_vendor_class,        0,                                      offsetof(Network, dhcp6_vendor_class)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 229 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Route.Source",                                    config_parse_route_section,                     ROUTE_DESTINATION,                      0},
#line 245 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Route.TCPRetransmissionTimeoutSec",               config_parse_route_section,                     ROUTE_METRIC_RTO_MIN,                   0},
#line 181 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.MPLSRouting",                             config_parse_tristate,                          0,                                      offsetof(Network, mpls_input)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 640 "../systemd/src/network/networkd-network-gperf.gperf"
      {"TokenBucketFilter.MPUBytes",                      config_parse_tbf_size,                          QDISC_KIND_TBF,                         0},
#line 158 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.IPv4Forwarding",                          config_parse_tristate,                          0,                                      offsetof(Network, ip_forwarding[0])},
#line 708 "../systemd/src/network/networkd-network-gperf.gperf"
      {"TokenBucketFilter.Burst",                         config_parse_tbf_size,                          QDISC_KIND_TBF,                         0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 648 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.IPv6Token",                               config_parse_address_generation_type,           0,                                      offsetof(Network, ndisc_tokens)},
      {(char*)0}, {(char*)0},
#line 162 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.IPv6AcceptRA",                            config_parse_tristate,                          0,                                      offsetof(Network, ndisc)},
#line 294 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.AllowList",                                config_parse_in_addr_prefixes,                  AF_INET,                                offsetof(Network, dhcp_allow_listed_ip)},
      {(char*)0},
#line 583 "../systemd/src/network/networkd-network-gperf.gperf"
      {"FairQueueingControlledDelay.Flows",               config_parse_fq_codel_u32,                      QDISC_KIND_FQ_CODEL,                    0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 174 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.PrimarySlave",                            config_parse_bool,                              0,                                      offsetof(Network, primary_slave)},
      {(char*)0},
#line 367 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPRelay.VirtualSubnetSelection",                config_parse_dhcp_option,                       /* check_length= */ true,               offsetof(Network, dhcp_relay_vss)},
      {(char*)0}, {(char*)0},
#line 300 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.InitialCongestionWindow",                  config_parse_tcp_window,                        0,                                      offsetof(Network, dhcp_initial_congestion_window)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 688 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.ForceDHCPv6PDOtherInformation",            config_parse_warn_compat,                       DISABLED_LEGACY,                        0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 139 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.IPv6StableSecretAddress",                 config_parse_in_addr_non_null,                  AF_INET6,                               offsetof(Network, ipv6ll_stable_secret)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 333 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.NetLabel",                                 config_parse_string,                            CONFIG_PARSE_STRING_SAFE,               offsetof(Network, dhcp6_netlabel)},
      {(char*)0}, {(char*)0},
#line 334 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.SendRelease",                              config_parse_bool,                              0,                                      offsetof(Network, dhcp6_send_release)},
      {(char*)0},
#line 236 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Route.IPv6Preference",                            config_parse_route_section,                     ROUTE_PREFERENCE,                       0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 417 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Bridge.MulticastFlood",                           config_parse_tristate,                          0,                                      offsetof(Network, multicast_flood)},
      {(char*)0},
#line 331 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.DUIDRawData",                              config_parse_duid_rawdata,                      0,                                      offsetof(Network, dhcp6_duid)},
#line 454 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6SendRA.HopLimit",                             config_parse_uint8,                             0,                                      offsetof(Network, router_hop_limit)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 441 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPPrefixDelegation.Announce",                   config_parse_bool,                              0,                                      offsetof(Network, dhcp_pd_announce)},
#line 461 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6SendRA.HomeAgent",                            config_parse_bool,                              0,                                      offsetof(Network, router_home_agent_information)},
      {(char*)0},
#line 442 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPPrefixDelegation.Assign",                     config_parse_bool,                              0,                                      offsetof(Network, dhcp_pd_assign)},
#line 312 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.UseDNR",                                   config_parse_tristate,                          0,                                      offsetof(Network, dhcp6_use_dnr)},
      {(char*)0},
#line 628 "../systemd/src/network/networkd-network-gperf.gperf"
      {"StochasticFairBlue.Parent",                       config_parse_qdisc_parent,                      QDISC_KIND_SFB,                         0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 274 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.SendHostname",                             config_parse_dhcp_send_hostname,                AF_INET,                                0},
#line 630 "../systemd/src/network/networkd-network-gperf.gperf"
      {"StochasticFairBlue.PacketLimit",                  config_parse_sfb_u32,                           QDISC_KIND_SFB,                         0},
      {(char*)0},
#line 469 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6Prefix.Assign",                               config_parse_prefix_boolean,                    0,                                      0},
#line 335 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.NFTSet",                                   config_parse_nft_set,                           NFT_SET_PARSE_NETWORK,                  offsetof(Network, dhcp6_nft_set_context)},
      {(char*)0},
#line 330 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.DUIDType",                                 config_parse_duid_type,                         0,                                      offsetof(Network, dhcp6_duid)},
      {(char*)0},
#line 657 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6PrefixDelegation.EmitDomains",                config_parse_bool,                              0,                                      offsetof(Network, router_emit_domains)},
#line 443 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPPrefixDelegation.ManageTemporaryAddress",     config_parse_bool,                              0,                                      offsetof(Network, dhcp_pd_manage_temporary_address)},
#line 532 "../systemd/src/network/networkd-network-gperf.gperf"
      {"CAKE.Wash",                                       config_parse_cake_tristate,                     QDISC_KIND_CAKE,                        0},
      {(char*)0}, {(char*)0},
#line 336 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.RouteTable",                               config_parse_dhcp_or_ra_route_table,            NETWORK_CONFIG_SOURCE_DHCP6,            0},
#line 341 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.UseOnLinkPrefix",                    config_parse_bool,                              0,                                      offsetof(Network, ndisc_use_onlink_prefix)},
      {(char*)0}, {(char*)0},
#line 444 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPPrefixDelegation.Token",                      config_parse_address_generation_type,           0,                                      offsetof(Network, dhcp_pd_tokens)},
#line 339 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.UseRoutePrefix",                     config_parse_bool,                              0,                                      offsetof(Network, ndisc_use_route_prefix)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 587 "../systemd/src/network/networkd-network-gperf.gperf"
      {"FairQueueingControlledDelay.CEThresholdSec",      config_parse_fq_codel_usec,                     QDISC_KIND_FQ_CODEL,                    0},
#line 163 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.IPv6AcceptRouterAdvertisements",          config_parse_tristate,                          0,                                      offsetof(Network, ndisc)},
      {(char*)0},
#line 428 "../systemd/src/network/networkd-network-gperf.gperf"
      {"BridgeFDB.MACAddress",                            config_parse_fdb_hwaddr,                        0,                                      0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 315 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.UseNTP",                                   config_parse_tristate,                          0,                                      offsetof(Network, dhcp6_use_ntp)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 202 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Address.NFTSet",                                  config_parse_address_section,                   ADDRESS_NFT_SET,                        0},
#line 503 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPoIB.Mode",                                      config_parse_ipoib_mode,                        0,                                      offsetof(Network, ipoib_mode)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 654 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6PrefixDelegation.RouterPreference",           config_parse_router_preference,                 0,                                      offsetof(Network, router_preference)},
#line 394 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.EmitDomain",                           config_parse_bool,                              0,                                      offsetof(Network, dhcp_server_emit_domain)},
      {(char*)0}, {(char*)0},
#line 639 "../systemd/src/network/networkd-network-gperf.gperf"
      {"TokenBucketFilter.MTUBytes",                      config_parse_tbf_size,                          QDISC_KIND_TBF,                         0},
#line 445 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPPrefixDelegation.RouteMetric",                config_parse_uint32,                            0,                                      offsetof(Network, dhcp_pd_route_metric)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 528 "../systemd/src/network/networkd-network-gperf.gperf"
      {"CAKE.FlowIsolationMode",                          config_parse_cake_flow_isolation_mode,          QDISC_KIND_CAKE,                        0},
#line 651 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6PrefixDelegation.RouterLifetimeSec",          config_parse_sec,                               0,                                      offsetof(Network, router_lifetime_usec)},
#line 457 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6SendRA.EmitDomains",                          config_parse_bool,                              0,                                      offsetof(Network, router_emit_domains)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 638 "../systemd/src/network/networkd-network-gperf.gperf"
      {"TokenBucketFilter.LimitBytes",                    config_parse_tbf_size,                          QDISC_KIND_TBF,                         0},
      {(char*)0},
#line 87 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Match.Name",                                      config_parse_match_ifnames,                     IFNAME_VALID_ALTERNATIVE,               offsetof(Network, match.ifname)},
      {(char*)0}, {(char*)0},
#line 199 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Address.Scope",                                   config_parse_address_section,                   ADDRESS_SCOPE,                          0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 402 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.BootServerName",                       config_parse_dns_name,                          0,                                      offsetof(Network, dhcp_server_boot_server_name)},
      {(char*)0},
#line 120 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.Bond",                                    config_parse_ifname,                            0,                                      offsetof(Network, bond_name)},
#line 549 "../systemd/src/network/networkd-network-gperf.gperf"
      {"EnhancedTransmissionSelection.Handle",            config_parse_qdisc_handle,                      QDISC_KIND_ETS,                         0},
      {(char*)0},
#line 128 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.MACVLAN",                                 config_parse_stacked_netdev,                    NETDEV_KIND_MACVLAN,                    offsetof(Network, stacked_netdev_names)},
      {(char*)0},
#line 550 "../systemd/src/network/networkd-network-gperf.gperf"
      {"EnhancedTransmissionSelection.Bands",             config_parse_ets_u8,                            QDISC_KIND_ETS,                         0},
#line 548 "../systemd/src/network/networkd-network-gperf.gperf"
      {"EnhancedTransmissionSelection.Parent",            config_parse_qdisc_parent,                      QDISC_KIND_ETS,                         0},
      {(char*)0},
#line 560 "../systemd/src/network/networkd-network-gperf.gperf"
      {"PFIFOHeadDrop.Handle",                            config_parse_qdisc_handle,                      QDISC_KIND_PFIFO_HEAD_DROP,             0},
      {(char*)0}, {(char*)0},
#line 551 "../systemd/src/network/networkd-network-gperf.gperf"
      {"EnhancedTransmissionSelection.StrictBands",       config_parse_ets_u8,                            QDISC_KIND_ETS,                         0},
#line 552 "../systemd/src/network/networkd-network-gperf.gperf"
      {"EnhancedTransmissionSelection.QuantumBytes",      config_parse_ets_quanta,                        QDISC_KIND_ETS,                         0},
#line 129 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.MACVTAP",                                 config_parse_stacked_netdev,                    NETDEV_KIND_MACVTAP,                    offsetof(Network, stacked_netdev_names)},
#line 272 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.RequestOptions",                           config_parse_dhcp_request_options,              AF_INET,                                0},
      {(char*)0},
#line 658 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6PrefixDelegation.Domains",                    config_parse_radv_search_domains,               0,                                      0},
      {(char*)0},
#line 559 "../systemd/src/network/networkd-network-gperf.gperf"
      {"PFIFOHeadDrop.Parent",                            config_parse_qdisc_parent,                      QDISC_KIND_PFIFO_HEAD_DROP,             0},
      {(char*)0},
#line 578 "../systemd/src/network/networkd-network-gperf.gperf"
      {"FairQueueing.CEThresholdSec",                     config_parse_fq_usec,                           QDISC_KIND_FQ,                          0},
#line 298 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.SendVendorOption",                         config_parse_dhcp_option_tlv,                   0,                                      offsetof(Network, dhcp_vendor_options)},
      {(char*)0},
#line 561 "../systemd/src/network/networkd-network-gperf.gperf"
      {"PFIFOHeadDrop.PacketLimit",                       config_parse_pfifo_size,                        QDISC_KIND_PFIFO_HEAD_DROP,             0},
#line 384 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.EmitPOP3",                             config_parse_bool,                              0,                                      offsetof(Network, dhcp_server_emit[SD_DHCP_LEASE_POP3].emit)},
#line 134 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.DHCP",                                    config_parse_dhcp,                              0,                                      offsetof(Network, dhcp)},
      {(char*)0},
#line 415 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Bridge.AllowPortToBeRoot",                        config_parse_tristate,                          0,                                      offsetof(Network, allow_port_to_be_root)},
      {(char*)0},
#line 177 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.ProxyARP",                                config_parse_tristate,                          0,                                      offsetof(Network, proxy_arp)},
      {(char*)0},
#line 317 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.UseCaptivePortal",                         config_parse_bool,                              0,                                      offsetof(Network, dhcp6_use_captive_portal)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 536 "../systemd/src/network/networkd-network-gperf.gperf"
      {"ControlledDelay.Parent",                          config_parse_qdisc_parent,                      QDISC_KIND_CODEL,                       0},
#line 637 "../systemd/src/network/networkd-network-gperf.gperf"
      {"TokenBucketFilter.BurstBytes",                    config_parse_tbf_size,                          QDISC_KIND_TBF,                         0},
#line 492 "../systemd/src/network/networkd-network-gperf.gperf"
      {"CAN.RestartSec",                                  config_parse_can_restart_usec,                  0,                                      offsetof(Network, can_restart_us)},
#line 380 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.EmitNTP",                              config_parse_bool,                              0,                                      offsetof(Network, dhcp_server_emit[SD_DHCP_LEASE_NTP].emit)},
      {(char*)0}, {(char*)0},
#line 118 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.KeepMaster",                              config_parse_bool,                              0,                                      offsetof(Network, keep_master)},
      {(char*)0}, {(char*)0},
#line 439 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPPrefixDelegation.UplinkInterface",            config_parse_uplink,                            0,                                      0},
#line 470 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6Prefix.RouteMetric",                          config_parse_prefix_metric,                     0,                                      0},
      {(char*)0},
#line 669 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCP.Anonymize",                                  config_parse_bool,                              0,                                      offsetof(Network, dhcp_anonymize)},
#line 169 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.IPv6MTUBytes",                            config_parse_mtu,                               AF_INET6,                               offsetof(Network, ipv6_mtu)},
      {(char*)0},
#line 487 "../systemd/src/network/networkd-network-gperf.gperf"
      {"CAN.DataTimeQuantaNSec",                          config_parse_can_time_quanta,                   0,                                      offsetof(Network, can_data_time_quanta_ns)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 681 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCP.UseTimezone",                                config_parse_bool,                              0,                                      offsetof(Network, dhcp_use_timezone)},
#line 119 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.BatmanAdvanced",                          config_parse_ifname,                            0,                                      offsetof(Network, batadv_name)},
#line 671 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCP.Hostname",                                   config_parse_hostname,                          0,                                      offsetof(Network, dhcp_hostname)},
#line 542 "../systemd/src/network/networkd-network-gperf.gperf"
      {"ControlledDelay.ECN",                             config_parse_codel_bool,                        QDISC_KIND_CODEL,                       0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 649 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.IPv6PrefixDelegation",                    config_parse_router_prefix_delegation,          0,                                      offsetof(Network, router_prefix_delegation)},
      {(char*)0}, {(char*)0},
#line 471 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6Prefix.Token",                                config_parse_prefix_token,                      0,                                      0},
      {(char*)0},
#line 225 "../systemd/src/network/networkd-network-gperf.gperf"
      {"RoutingPolicyRule.SuppressPrefixLength",          config_parse_routing_policy_rule,               ROUTING_POLICY_RULE_SUPPRESS_PREFIXLEN, 0},
      {(char*)0},
#line 539 "../systemd/src/network/networkd-network-gperf.gperf"
      {"ControlledDelay.TargetSec",                       config_parse_codel_usec,                        QDISC_KIND_CODEL,                       0},
#line 371 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.UplinkInterface",                      config_parse_uplink,                            0,                                      0},
#line 538 "../systemd/src/network/networkd-network-gperf.gperf"
      {"ControlledDelay.PacketLimit",                     config_parse_codel_u32,                         QDISC_KIND_CODEL,                       0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 460 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6SendRA.UplinkInterface",                      config_parse_uplink,                            0,                                      0},
#line 340 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.UseAutonomousPrefix",                config_parse_bool,                              0,                                      offsetof(Network, ndisc_use_autonomous_prefix)},
#line 167 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.IPv6RetransmissionTimeSec",               config_parse_sec,                               0,                                      offsetof(Network, ipv6_retransmission_time)},
      {(char*)0}, {(char*)0},
#line 322 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.UserClass",                                config_parse_dhcp6_user_or_vendor_class,        0,                                      offsetof(Network, dhcp6_user_class)},
#line 447 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPPrefixDelegation.NFTSet",                     config_parse_nft_set,                           NFT_SET_PARSE_NETWORK,                  offsetof(Network, dhcp_pd_nft_set_context)},
      {(char*)0},
#line 346 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.UseMTU",                             config_parse_bool,                              0,                                      offsetof(Network, ndisc_use_mtu)},
#line 466 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6Prefix.AddressAutoconfiguration",             config_parse_prefix_boolean,                    ND_OPT_PI_FLAG_AUTO,                    0},
      {(char*)0},
#line 270 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.UseGateway",                               config_parse_tristate,                          0,                                      offsetof(Network, dhcp_use_gateway)},
#line 338 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.UseGateway",                         config_parse_bool,                              0,                                      offsetof(Network, ndisc_use_gateway)},
      {(char*)0}, {(char*)0},
#line 232 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Route.PreferredSource",                           config_parse_route_section,                     ROUTE_PREFERRED_SOURCE,                 0},
      {(char*)0}, {(char*)0},
#line 370 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.ServerAddress",                        config_parse_dhcp_server_address,               0,                                      0},
      {(char*)0},
#line 296 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.SocketPriority",                           config_parse_dhcp_socket_priority,              0,                                      offsetof(Network, dhcp_socket_priority)},
      {(char*)0},
#line 180 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.MulticastIGMPVersion",                    config_parse_ipv4_force_igmp_version,           0,                                      offsetof(Network, ipv4_force_igmp_version)},
      {(char*)0},
#line 175 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.IPv4ProxyARP",                            config_parse_tristate,                          0,                                      offsetof(Network, proxy_arp)},
      {(char*)0},
#line 81 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Match.Driver",                                    config_parse_match_strv,                        0,                                      offsetof(Network, match.driver)},
      {(char*)0},
#line 254 "../systemd/src/network/networkd-network-gperf.gperf"
      {"NextHop.OnLink",                                  config_parse_nexthop_section,                   NEXTHOP_ONLINK,                         0},
      {(char*)0},
#line 377 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.IPv6OnlyPreferredSec",                 config_parse_dhcp_server_ipv6_only_preferred,   0,                                      offsetof(Network, dhcp_server_ipv6_only_preferred_usec)},
      {(char*)0},
#line 390 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.EmitRouter",                           config_parse_bool,                              0,                                      offsetof(Network, dhcp_server_emit_router)},
      {(char*)0}, {(char*)0},
#line 398 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.SendOption",                           config_parse_dhcp_option_tlv,                   0,                                      offsetof(Network, dhcp_server_extra_options)},
      {(char*)0}, {(char*)0},
#line 154 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.DNSSEC",                                  config_parse_dnssec_mode,                       0,                                      offsetof(Network, dnssec_mode)},
#line 146 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.Gateway",                                 config_parse_route_section,                     ROUTE_GATEWAY_NETWORK,                  0},
      {(char*)0},
#line 230 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Route.Metric",                                    config_parse_route_section,                     ROUTE_PRIORITY,                         0},
      {(char*)0}, {(char*)0},
#line 463 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6SendRA.HomeAgentPreference",                  config_parse_uint16,                            0,                                      offsetof(Network, router_home_agent_preference)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 293 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.DenyList",                                 config_parse_in_addr_prefixes,                  AF_INET,                                offsetof(Network, dhcp_deny_listed_ip)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 82 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Match.Type",                                      config_parse_match_strv,                        0,                                      offsetof(Network, match.iftype)},
#line 665 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCP.UseHostname",                                config_parse_bool,                              0,                                      offsetof(Network, dhcp_use_hostname)},
#line 309 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.UseAddress",                               config_parse_bool,                              0,                                      offsetof(Network, dhcp6_use_address)},
#line 136 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.DHCPServer",                              config_parse_bool,                              0,                                      offsetof(Network, dhcp_server)},
#line 668 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCP.UseRoutes",                                  config_parse_bool,                              0,                                      offsetof(Network, dhcp_use_routes)},
#line 666 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCP.UseDomains",                                 config_parse_use_domains,                       0,                                      offsetof(Network, compat_dhcp_use_domains)},
      {(char*)0},
#line 481 "../systemd/src/network/networkd-network-gperf.gperf"
      {"CAN.PropagationSegment",                          config_parse_uint32,                            0,                                      offsetof(Network, can_propagation_segment)},
#line 667 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCP.UseDomainName",                              config_parse_use_domains,                       0,                                      offsetof(Network, compat_dhcp_use_domains)},
      {(char*)0},
#line 682 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCP.ListenPort",                                 config_parse_uint16,                            0,                                      offsetof(Network, dhcp_client_port)},
      {(char*)0},
#line 358 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.PrefixDenyList",                     config_parse_in_addr_prefixes,                  AF_INET6,                               offsetof(Network, ndisc_deny_listed_prefix)},
#line 544 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DeficitRoundRobinScheduler.Handle",               config_parse_qdisc_handle,                      QDISC_KIND_DRR,                         0},
#line 347 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.UseHopLimit",                        config_parse_bool,                              0,                                      offsetof(Network, ndisc_use_hop_limit)},
      {(char*)0},
#line 273 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.Anonymize",                                config_parse_bool,                              0,                                      offsetof(Network, dhcp_anonymize)},
#line 500 "../systemd/src/network/networkd-network-gperf.gperf"
      {"CAN.FDNonISO",                                    config_parse_can_control_mode,                  CAN_CTRLMODE_FD_NON_ISO,                0},
#line 543 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DeficitRoundRobinScheduler.Parent",               config_parse_qdisc_parent,                      QDISC_KIND_DRR,                         0},
      {(char*)0},
#line 392 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.EmitTimezone",                         config_parse_bool,                              0,                                      offsetof(Network, dhcp_server_emit_timezone)},
#line 86 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Match.BSSID",                                     config_parse_ether_addrs,                       0,                                      offsetof(Network, match.bssid)},
#line 328 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.SendOption",                               config_parse_dhcp6_send_option,                 0,                                      offsetof(Network, dhcp6_client_send_options)},
#line 545 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DeficitRoundRobinSchedulerClass.Parent",          config_parse_tclass_parent,                     TCLASS_KIND_DRR,                        0},
#line 92 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Match.KernelVersion",                             config_parse_net_condition,                     CONDITION_VERSION,                      offsetof(Network, conditions)},
      {(char*)0},
#line 103 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Link.Promiscuous",                                config_parse_tristate,                          0,                                      offsetof(Network, promiscuous)},
      {(char*)0}, {(char*)0},
#line 547 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DeficitRoundRobinSchedulerClass.QuantumBytes",    config_parse_drr_size,                          TCLASS_KIND_DRR,                        0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 601 "../systemd/src/network/networkd-network-gperf.gperf"
      {"HierarchyTokenBucket.Handle",                     config_parse_qdisc_handle,                      QDISC_KIND_HTB,                         0},
      {(char*)0}, {(char*)0},
#line 436 "../systemd/src/network/networkd-network-gperf.gperf"
      {"BridgeVLAN.PVID",                                 config_parse_bridge_vlan_id,                    0,                                      offsetof(Network, bridge_vlan_pvid)},
      {(char*)0},
#line 600 "../systemd/src/network/networkd-network-gperf.gperf"
      {"HierarchyTokenBucket.Parent",                     config_parse_qdisc_parent,                      QDISC_KIND_HTB,                         0},
      {(char*)0},
#line 446 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPPrefixDelegation.NetLabel",                   config_parse_string,                            CONFIG_PARSE_STRING_SAFE,               offsetof(Network, dhcp_pd_netlabel)},
      {(char*)0}, {(char*)0},
#line 540 "../systemd/src/network/networkd-network-gperf.gperf"
      {"ControlledDelay.IntervalSec",                     config_parse_codel_usec,                        QDISC_KIND_CODEL,                       0},
      {(char*)0},
#line 611 "../systemd/src/network/networkd-network-gperf.gperf"
      {"HierarchyTokenBucketClass.CeilRate",              config_parse_htb_class_rate,                    TCLASS_KIND_HTB,                        0},
#line 610 "../systemd/src/network/networkd-network-gperf.gperf"
      {"HierarchyTokenBucketClass.Rate",                  config_parse_htb_class_rate,                    TCLASS_KIND_HTB,                        0},
      {(char*)0},
#line 604 "../systemd/src/network/networkd-network-gperf.gperf"
      {"HierarchyTokenBucketClass.Parent",                config_parse_tclass_parent,                     TCLASS_KIND_HTB,                        0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 480 "../systemd/src/network/networkd-network-gperf.gperf"
      {"CAN.TimeQuantaNSec",                              config_parse_can_time_quanta,                   0,                                      offsetof(Network, can_time_quanta_ns)},
#line 609 "../systemd/src/network/networkd-network-gperf.gperf"
      {"HierarchyTokenBucketClass.OverheadBytes",         config_parse_htb_class_size,                    TCLASS_KIND_HTB,                        0},
      {(char*)0},
#line 613 "../systemd/src/network/networkd-network-gperf.gperf"
      {"HierarchyTokenBucketClass.CeilBufferBytes",       config_parse_htb_class_size,                    TCLASS_KIND_HTB,                        0},
#line 356 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.RouterDenyList",                     config_parse_in_addr_prefixes,                  AF_INET6,                               offsetof(Network, ndisc_deny_listed_router)},
#line 607 "../systemd/src/network/networkd-network-gperf.gperf"
      {"HierarchyTokenBucketClass.QuantumBytes",          config_parse_htb_class_size,                    TCLASS_KIND_HTB,                        0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 187 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.DHCPPrefixDelegation",                    config_parse_tristate,                          0,                                      offsetof(Network, dhcp_pd)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 131 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.VLAN",                                    config_parse_stacked_netdev,                    NETDEV_KIND_VLAN,                       offsetof(Network, stacked_netdev_names)},
#line 240 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Route.NextHop",                                   config_parse_route_section,                     ROUTE_NEXTHOP,                          0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 647 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.IPv4LL",                                  config_parse_ipv4ll,                            0,                                      offsetof(Network, link_local)},
      {(char*)0}, {(char*)0},
#line 372 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.RelayTarget",                          config_parse_in_addr_non_null,                  AF_INET,                                offsetof(Network, dhcp_relay_target_address) /* deprecated */},
#line 186 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.IPv6SendRA",                              config_parse_router_prefix_delegation,          0,                                      offsetof(Network, router_prefix_delegation)},
#line 124 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.IPVLAN",                                  config_parse_stacked_netdev,                    NETDEV_KIND_IPVLAN,                     offsetof(Network, stacked_netdev_names)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 389 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.LPR",                                  config_parse_dhcp_server_emit,                  0,                                      offsetof(Network, dhcp_server_emit[SD_DHCP_LEASE_LPR])},
#line 248 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Route.TCPCongestionControlAlgorithm",             config_parse_route_section,                     ROUTE_METRIC_CC_ALGO,                   0},
      {(char*)0},
#line 143 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.LLDP",                                    config_parse_lldp_mode,                         0,                                      offsetof(Network, lldp_mode)},
#line 596 "../systemd/src/network/networkd-network-gperf.gperf"
      {"GenericRandomEarlyDetection.GenericRIO",          config_parse_gred_bool,                         QDISC_KIND_GRED,                        0},
      {(char*)0},
#line 423 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Bridge.Priority",                                 config_parse_bridge_port_priority,              0,                                      offsetof(Network, priority)},
      {(char*)0},
#line 106 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Link.RequiredForOnline",                          config_parse_required_for_online,               0,                                      0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 266 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.UseMTU",                                   config_parse_bool,                              0,                                      offsetof(Network, dhcp_use_mtu)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 280 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.MUDURL",                                   config_parse_mud_url,                           0,                                      offsetof(Network, dhcp_mudurl)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 465 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6Prefix.OnLink",                               config_parse_prefix_boolean,                    ND_OPT_PI_FLAG_ONLINK,                  0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 663 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCP.UseNTP",                                     config_parse_tristate,                          0,                                      offsetof(Network, compat_dhcp_use_ntp)},
      {(char*)0},
#line 100 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Link.ARP",                                        config_parse_tristate,                          0,                                      offsetof(Network, arp)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 411 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Bridge.UseBPDU",                                  config_parse_tristate,                          0,                                      offsetof(Network, use_bpdu)},
      {(char*)0},
#line 246 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Route.InitialAdvertisedReceiveWindow",            config_parse_route_section,                     ROUTE_METRIC_INITRWND,                  0},
      {(char*)0},
#line 401 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.BootServerAddress",                    config_parse_in_addr_non_null,                  AF_INET,                                offsetof(Network, dhcp_server_boot_server_address)},
      {(char*)0},
#line 498 "../systemd/src/network/networkd-network-gperf.gperf"
      {"CAN.FDMode",                                      config_parse_can_control_mode,                  CAN_CTRLMODE_FD,                        0},
      {(char*)0}, {(char*)0},
#line 652 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6PrefixDelegation.Managed",                    config_parse_bool,                              0,                                      offsetof(Network, router_managed)},
      {(char*)0},
#line 239 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Route.MultiPathRoute",                            config_parse_route_section,                     ROUTE_MULTIPATH,                        0},
#line 414 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Bridge.FastLeave",                                config_parse_tristate,                          0,                                      offsetof(Network, fast_leave)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 565 "../systemd/src/network/networkd-network-gperf.gperf"
      {"QuickFairQueueingClass.ClassId",                  config_parse_tclass_classid,                    TCLASS_KIND_QFQ,                        0},
      {(char*)0},
#line 102 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Link.AllMulticast",                               config_parse_tristate,                          0,                                      offsetof(Network, allmulticast)},
      {(char*)0},
#line 241 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Route.MTUBytes",                                  config_parse_route_section,                     ROUTE_METRIC_MTU,                       0},
      {(char*)0},
#line 526 "../systemd/src/network/networkd-network-gperf.gperf"
      {"CAKE.CompensationMode",                           config_parse_cake_compensation_mode,            QDISC_KIND_CAKE,                        0},
#line 555 "../systemd/src/network/networkd-network-gperf.gperf"
      {"PFIFO.Handle",                                    config_parse_qdisc_handle,                      QDISC_KIND_PFIFO,                       0},
#line 153 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.DNSOverTLS",                              config_parse_dns_over_tls_mode,                 0,                                      offsetof(Network, dns_over_tls_mode)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 590 "../systemd/src/network/networkd-network-gperf.gperf"
      {"FlowQueuePIE.Handle",                             config_parse_qdisc_handle,                      QDISC_KIND_FQ_PIE,                      0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 185 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.KeepConfiguration",                       config_parse_keep_configuration,                0,                                      offsetof(Network, keep_configuration)},
#line 589 "../systemd/src/network/networkd-network-gperf.gperf"
      {"FlowQueuePIE.Parent",                             config_parse_qdisc_parent,                      QDISC_KIND_FQ_PIE,                      0},
      {(char*)0}, {(char*)0},
#line 96 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Match.Firmware",                                  config_parse_net_condition,                     CONDITION_FIRMWARE,                     offsetof(Network, conditions)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 151 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.LLMNR",                                   config_parse_resolve_support,                   0,                                      offsetof(Network, llmnr)},
#line 574 "../systemd/src/network/networkd-network-gperf.gperf"
      {"FairQueueing.MaximumRate",                        config_parse_fq_max_rate,                       QDISC_KIND_FQ,                          0},
      {(char*)0},
#line 674 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCP.VendorClassIdentifier",                      config_parse_string,                            CONFIG_PARSE_STRING_SAFE,               offsetof(Network, dhcp_vendor_class_identifier)},
#line 359 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6AcceptRA.RouteAllowList",                     config_parse_in_addr_prefixes,                  AF_INET6,                               offsetof(Network, ndisc_allow_listed_route_prefix)},
      {(char*)0},
#line 593 "../systemd/src/network/networkd-network-gperf.gperf"
      {"GenericRandomEarlyDetection.Handle",              config_parse_qdisc_handle,                      QDISC_KIND_GRED,                        0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 603 "../systemd/src/network/networkd-network-gperf.gperf"
      {"HierarchyTokenBucket.RateToQuantum",              config_parse_htb_u32,                           QDISC_KIND_HTB,                         0},
      {(char*)0},
#line 419 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Bridge.NeighborSuppression",                      config_parse_tristate,                          0,                                      offsetof(Network, neighbor_suppression)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 521 "../systemd/src/network/networkd-network-gperf.gperf"
      {"CAKE.Handle",                                     config_parse_qdisc_handle,                      QDISC_KIND_CAKE,                        0},
#line 406 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.LocalLeaseDomain",                     config_parse_dns_name,                          0,                                      offsetof(Network, dhcp_server_local_lease_domain)},
      {(char*)0}, {(char*)0},
#line 421 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Bridge.ProxyARP",                                 config_parse_tristate,                          0,                                      offsetof(Network, bridge_proxy_arp)},
      {(char*)0},
#line 255 "../systemd/src/network/networkd-network-gperf.gperf"
      {"NextHop.Blackhole",                               config_parse_nexthop_section,                   NEXTHOP_BLACKHOLE,                      0},
#line 311 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.UseDNS",                                   config_parse_tristate,                          0,                                      offsetof(Network, dhcp6_use_dns)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 516 "../systemd/src/network/networkd-network-gperf.gperf"
      {"QDisc.Handle",                                    config_parse_qdisc_handle,                      _QDISC_KIND_INVALID,                    0},
      {(char*)0},
#line 422 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Bridge.ProxyARPWiFi",                             config_parse_tristate,                          0,                                      offsetof(Network, bridge_proxy_arp_wifi)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 594 "../systemd/src/network/networkd-network-gperf.gperf"
      {"GenericRandomEarlyDetection.VirtualQueues",       config_parse_gred_u32,                          QDISC_KIND_GRED,                        0},
      {(char*)0}, {(char*)0},
#line 580 "../systemd/src/network/networkd-network-gperf.gperf"
      {"FairQueueingControlledDelay.Handle",              config_parse_qdisc_handle,                      QDISC_KIND_FQ_CODEL,                    0},
      {(char*)0},
#line 201 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Address.NetLabel",                                config_parse_address_section,                   ADDRESS_NET_LABEL,                      0},
#line 709 "../systemd/src/network/networkd-network-gperf.gperf"
      {"TokenBucketFilter.LimitSize",                     config_parse_tbf_size,                          QDISC_KIND_TBF,                         0},
#line 451 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6SendRA.Managed",                              config_parse_bool,                              0,                                      offsetof(Network, router_managed)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 524 "../systemd/src/network/networkd-network-gperf.gperf"
      {"CAKE.OverheadBytes",                              config_parse_cake_overhead,                     QDISC_KIND_CAKE,                        0},
#line 494 "../systemd/src/network/networkd-network-gperf.gperf"
      {"CAN.ListenOnly",                                  config_parse_can_control_mode,                  CAN_CTRLMODE_LISTENONLY,                0},
      {(char*)0}, {(char*)0},
#line 164 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.IPv6DuplicateAddressDetection",           config_parse_int,                               0,                                      offsetof(Network, ipv6_dad_transmits)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 612 "../systemd/src/network/networkd-network-gperf.gperf"
      {"HierarchyTokenBucketClass.BufferBytes",           config_parse_htb_class_size,                    TCLASS_KIND_HTB,                        0},
      {(char*)0},
#line 675 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCP.UserClass",                                  config_parse_dhcp4_user_class,                  0,                                      offsetof(Network, dhcp_user_class)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 486 "../systemd/src/network/networkd-network-gperf.gperf"
      {"CAN.DataSamplePoint",                             config_parse_permille,                          0,                                      offsetof(Network, can_data_sample_point)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 152 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.MulticastDNS",                            config_parse_resolve_support,                   0,                                      offsetof(Network, mdns)},
      {(char*)0},
#line 537 "../systemd/src/network/networkd-network-gperf.gperf"
      {"ControlledDelay.Handle",                          config_parse_qdisc_handle,                      QDISC_KIND_CODEL,                       0},
      {(char*)0},
#line 207 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Neighbor.MACAddress",                             config_parse_neighbor_section,                  NEIGHBOR_LINK_LAYER_ADDRESS,            0 /* deprecated */},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 84 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Match.WLANInterfaceType",                         config_parse_match_strv,                        0,                                      offsetof(Network, match.wlan_iftype)},
#line 644 "../systemd/src/network/networkd-network-gperf.gperf"
      {"TrivialLinkEqualizer.Handle",                     config_parse_qdisc_handle,                      QDISC_KIND_TEQL,                        0},
      {(char*)0}, {(char*)0},
#line 531 "../systemd/src/network/networkd-network-gperf.gperf"
      {"CAKE.FirewallMark",                               config_parse_cake_fwmark,                       QDISC_KIND_CAKE,                        0},
      {(char*)0},
#line 643 "../systemd/src/network/networkd-network-gperf.gperf"
      {"TrivialLinkEqualizer.Parent",                     config_parse_qdisc_parent,                      QDISC_KIND_TEQL,                        0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 368 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPRelay.ExtraOption",                           config_parse_dhcp_option_tlv,                   0,                                      offsetof(Network, dhcp_relay_extra_options)},
#line 369 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPRelay.InterfacePriority",                     config_parse_int,                               0,                                      offsetof(Network, dhcp_relay_interface_priority)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 527 "../systemd/src/network/networkd-network-gperf.gperf"
      {"CAKE.UseRawPacketSize",                           config_parse_cake_tristate,                     QDISC_KIND_CAKE,                        0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 159 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.IPv6Forwarding",                          config_parse_tristate,                          0,                                      offsetof(Network, ip_forwarding[1])},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 518 "../systemd/src/network/networkd-network-gperf.gperf"
      {"BFIFO.Handle",                                    config_parse_qdisc_handle,                      QDISC_KIND_BFIFO,                       0},
      {(char*)0},
#line 570 "../systemd/src/network/networkd-network-gperf.gperf"
      {"FairQueueing.PacketLimit",                        config_parse_fq_u32,                            QDISC_KIND_FQ,                          0},
      {(char*)0}, {(char*)0},
#line 567 "../systemd/src/network/networkd-network-gperf.gperf"
      {"QuickFairQueueingClass.MaxPacketBytes",           config_parse_qfq_max_packet,                    TCLASS_KIND_QFQ,                        0},
      {(char*)0},
#line 706 "../systemd/src/network/networkd-network-gperf.gperf"
      {"FairQueueingControlledDelay.MemoryLimit",         config_parse_fq_codel_size,                     QDISC_KIND_FQ_CODEL,                    0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 95 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Match.Architecture",                              config_parse_net_condition,                     CONDITION_ARCHITECTURE,                 offsetof(Network, conditions)},
#line 582 "../systemd/src/network/networkd-network-gperf.gperf"
      {"FairQueueingControlledDelay.MemoryLimitBytes",    config_parse_fq_codel_size,                     QDISC_KIND_FQ_CODEL,                    0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 244 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Route.InitialCongestionWindow",                   config_parse_route_section,                     ROUTE_METRIC_INITCWND,                  0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 305 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.IPv6OnlyMode",                             config_parse_tristate,                          0,                                      offsetof(Network, dhcp_ipv6_only_mode)},
      {(char*)0}, {(char*)0},
#line 249 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Route.FastOpenNoCookie",                          config_parse_route_section,                     ROUTE_METRIC_FASTOPEN_NO_COOKIE,        0},
#line 588 "../systemd/src/network/networkd-network-gperf.gperf"
      {"FairQueueingControlledDelay.ECN",                 config_parse_fq_codel_bool,                     QDISC_KIND_FQ_CODEL,                    0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 519 "../systemd/src/network/networkd-network-gperf.gperf"
      {"BFIFO.LimitBytes",                                config_parse_bfifo_size,                        QDISC_KIND_BFIFO,                       0},
      {(char*)0},
#line 308 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.RapidCommit",                              config_parse_tristate,                          0,                                      offsetof(Network, dhcp_use_rapid_commit)},
#line 172 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.IPv4SrcValidMark",                        config_parse_tristate,                          0,                                      offsetof(Network, ipv4_src_valid_mark)},
      {(char*)0}, {(char*)0},
#line 301 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.InitialAdvertisedReceiveWindow",           config_parse_tcp_window,                        0,                                      offsetof(Network, dhcp_advertised_receive_window)},
#line 655 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6PrefixDelegation.EmitDNS",                    config_parse_bool,                              0,                                      offsetof(Network, router_emit_dns)},
      {(char*)0},
#line 224 "../systemd/src/network/networkd-network-gperf.gperf"
      {"RoutingPolicyRule.SuppressInterfaceGroup",        config_parse_routing_policy_rule,               ROUTING_POLICY_RULE_SUPPRESS_IFGROUP,   0},
      {(char*)0},
#line 226 "../systemd/src/network/networkd-network-gperf.gperf"
      {"RoutingPolicyRule.Type",                          config_parse_routing_policy_rule,               ROUTING_POLICY_RULE_ACTION,             0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 209 "../systemd/src/network/networkd-network-gperf.gperf"
      {"RoutingPolicyRule.Priority",                      config_parse_routing_policy_rule,               ROUTING_POLICY_RULE_PRIORITY,           0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 462 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6SendRA.HomeAgentLifetimeSec",                 config_parse_router_home_agent_lifetime,        0,                                      offsetof(Network, home_agent_lifetime_usec)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 659 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6PrefixDelegation.DNSLifetimeSec",             config_parse_sec,                               0,                                      offsetof(Network, router_dns_lifetime_usec)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 319 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.SendHostname",                             config_parse_dhcp_send_hostname,                AF_INET6,                               0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 227 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Route.Gateway",                                   config_parse_route_section,                     ROUTE_GATEWAY,                          0},
#line 546 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DeficitRoundRobinSchedulerClass.ClassId",         config_parse_tclass_classid,                    TCLASS_KIND_DRR,                        0},
      {(char*)0}, {(char*)0},
#line 573 "../systemd/src/network/networkd-network-gperf.gperf"
      {"FairQueueing.InitialQuantumBytes",                config_parse_fq_size,                           QDISC_KIND_FQ,                          0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 85 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Match.SSID",                                      config_parse_match_strv,                        0,                                      offsetof(Network, match.ssid)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 378 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.EmitDNS",                              config_parse_bool,                              0,                                      offsetof(Network, dhcp_server_emit[SD_DHCP_LEASE_DNS].emit)},
      {(char*)0},
#line 114 "../systemd/src/network/networkd-network-gperf.gperf"
      {"SR-IOV.Trust",                                    config_parse_sr_iov_boolean,                    0,                                      offsetof(Network, sr_iov_by_section)},
      {(char*)0}, {(char*)0},
#line 455 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6SendRA.EmitDNS",                              config_parse_bool,                              0,                                      offsetof(Network, router_emit_dns)},
      {(char*)0},
#line 653 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6PrefixDelegation.OtherInformation",           config_parse_bool,                              0,                                      offsetof(Network, router_other_information)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 605 "../systemd/src/network/networkd-network-gperf.gperf"
      {"HierarchyTokenBucketClass.ClassId",               config_parse_tclass_classid,                    TCLASS_KIND_HTB,                        0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 242 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Route.TCPAdvertisedMaximumSegmentSize",           config_parse_route_section,                     ROUTE_METRIC_ADVMSS,                    0},
#line 510 "../systemd/src/network/networkd-network-gperf.gperf"
      {"MobileNetwork.User",                              config_parse_string,                            CONFIG_PARSE_STRING_SAFE_AND_ASCII,     offsetof(Network, mm_user)},
      {(char*)0},
#line 310 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.UseDelegatedPrefix",                       config_parse_bool,                              0,                                      offsetof(Network, dhcp6_use_pd_prefix)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 670 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCP.SendHostname",                               config_parse_dhcp_send_hostname,                AF_UNSPEC,                              0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 399 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.SendVendorOption",                     config_parse_dhcp_option_tlv,                   0,                                      offsetof(Network, dhcp_server_vendor_options)},
      {(char*)0}, {(char*)0},
#line 373 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.RelayAgentCircuitId",                  config_parse_dhcp_option,                       /* check_length= */ true,               offsetof(Network, dhcp_relay_circuit_id) /* deprecated */},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 382 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.EmitSIP",                              config_parse_bool,                              0,                                      offsetof(Network, dhcp_server_emit[SD_DHCP_LEASE_SIP].emit)},
#line 386 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.EmitSMTP",                             config_parse_bool,                              0,                                      offsetof(Network, dhcp_server_emit[SD_DHCP_LEASE_SMTP].emit)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 512 "../systemd/src/network/networkd-network-gperf.gperf"
      {"MobileNetwork.PIN",                               config_parse_string,                            CONFIG_PARSE_STRING_SAFE_AND_ASCII,     offsetof(Network, mm_pin)},
#line 107 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Link.RequiredFamilyForOnline",                    config_parse_required_family_for_online,        0,                                      offsetof(Network, required_family_for_online)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 108 "../systemd/src/network/networkd-network-gperf.gperf"
      {"SR-IOV.VirtualFunction",                          config_parse_sr_iov_uint32,                     0,                                      offsetof(Network, sr_iov_by_section)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 234 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Route.GatewayOnLink",                             config_parse_route_section,                     ROUTE_GATEWAY_ONLINK,                   0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 321 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.RequestOptions",                           config_parse_dhcp_request_options,              AF_INET6,                               0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 138 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.IPv6LinkLocalAddressGenerationMode",      config_parse_ipv6_link_local_address_gen_mode,  0,                                      offsetof(Network, ipv6ll_address_gen_mode)},
#line 324 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.SendVendorOption",                         config_parse_dhcp6_send_option,                 0,                                      offsetof(Network, dhcp6_client_send_vendor_options)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 505 "../systemd/src/network/networkd-network-gperf.gperf"
      {"MobileNetwork.APN",                               config_parse_string,                            CONFIG_PARSE_STRING_SAFE_AND_ASCII,     offsetof(Network, mm_apn)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 662 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCP.UseDNS",                                     config_parse_tristate,                          0,                                      offsetof(Network, compat_dhcp_use_dns)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 325 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.PrefixDelegationHint",                     config_parse_dhcp6_pd_prefix_hint,              0,                                      0},
      {(char*)0},
#line 440 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPPrefixDelegation.SubnetId",                   config_parse_dhcp_pd_subnet_id,                 0,                                      offsetof(Network, dhcp_pd_subnet_id)},
      {(char*)0}, {(char*)0},
#line 178 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.IPv6ProxyNDPAddress",                     config_parse_ipv6_proxy_ndp_address,            0,                                      0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 231 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Route.Scope",                                     config_parse_route_section,                     ROUTE_SCOPE,                            0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 489 "../systemd/src/network/networkd-network-gperf.gperf"
      {"CAN.DataPhaseBufferSegment1",                     config_parse_uint32,                            0,                                      offsetof(Network, can_data_phase_buffer_segment_1)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 168 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.IPv6ProxyNDP",                            config_parse_tristate,                          0,                                      offsetof(Network, ipv6_proxy_ndp)},
#line 208 "../systemd/src/network/networkd-network-gperf.gperf"
      {"RoutingPolicyRule.TypeOfService",                 config_parse_routing_policy_rule,               ROUTING_POLICY_RULE_TOS,                0},
#line 464 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6Prefix.Prefix",                               config_parse_prefix,                            0,                                      0},
#line 602 "../systemd/src/network/networkd-network-gperf.gperf"
      {"HierarchyTokenBucket.DefaultClass",               config_parse_htb_default_class,                 QDISC_KIND_HTB,                         0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 490 "../systemd/src/network/networkd-network-gperf.gperf"
      {"CAN.DataPhaseBufferSegment2",                     config_parse_uint32,                            0,                                      offsetof(Network, can_data_phase_buffer_segment_2)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 507 "../systemd/src/network/networkd-network-gperf.gperf"
      {"MobileNetwork.AllowedAuthenticationMechanisms",   config_parse_mm_allowed_auth,                   0,                                      offsetof(Network, mm_allowed_auth)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 89 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Match.Host",                                      config_parse_net_condition,                     CONDITION_HOST,                         offsetof(Network, conditions)},
#line 375 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.MaxLeaseTimeSec",                      config_parse_sec,                               0,                                      offsetof(Network, dhcp_server_max_lease_time_usec)},
      {(char*)0}, {(char*)0},
#line 111 "../systemd/src/network/networkd-network-gperf.gperf"
      {"SR-IOV.VLANProtocol",                             config_parse_sr_iov_vlan_proto,                 0,                                      offsetof(Network, sr_iov_by_section)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 83 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Match.Kind",                                      config_parse_match_strv,                        0,                                      offsetof(Network, match.kind)},
#line 678 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCP.DUIDRawData",                                config_parse_network_duid_rawdata,              0,                                      0},
      {(char*)0}, {(char*)0},
#line 691 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv6PrefixDelegation.Assign",                   config_parse_bool,                              0,                                      offsetof(Network, dhcp_pd_assign)},
#line 629 "../systemd/src/network/networkd-network-gperf.gperf"
      {"StochasticFairBlue.Handle",                       config_parse_qdisc_handle,                      QDISC_KIND_SFB,                         0},
#line 690 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv6PrefixDelegation.Announce",                 config_parse_bool,                              0,                                      offsetof(Network, dhcp_pd_announce)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 90 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Match.Virtualization",                            config_parse_net_condition,                     CONDITION_VIRTUALIZATION,               offsetof(Network, conditions)},
      {(char*)0}, {(char*)0},
#line 281 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.MaxAttempts",                              config_parse_dhcp_max_attempts,                 0,                                      0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 645 "../systemd/src/network/networkd-network-gperf.gperf"
      {"TrivialLinkEqualizer.Id",                         config_parse_teql_id,                           QDISC_KIND_TEQL,                        0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 432 "../systemd/src/network/networkd-network-gperf.gperf"
      {"BridgeFDB.AssociatedWith",                        config_parse_fdb_ntf_flags,                     0,                                      0},
#line 251 "../systemd/src/network/networkd-network-gperf.gperf"
      {"NextHop.Id",                                      config_parse_nexthop_section,                   NEXTHOP_ID,                             0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 93 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Match.Version",                                   config_parse_net_condition,                     CONDITION_VERSION,                      offsetof(Network, conditions)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 166 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.IPv6HopLimit",                            config_parse_uint8,                             0,                                      offsetof(Network, ipv6_hop_limit)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 650 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.DHCPv6PrefixDelegation",                  config_parse_tristate,                          0,                                      offsetof(Network, dhcp_pd)},
      {(char*)0}, {(char*)0},
#line 110 "../systemd/src/network/networkd-network-gperf.gperf"
      {"SR-IOV.QualityOfService",                         config_parse_sr_iov_uint32,                     0,                                      offsetof(Network, sr_iov_by_section)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 318 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.MUDURL",                                   config_parse_mud_url,                           0,                                      offsetof(Network, dhcp6_mudurl)},
      {(char*)0}, {(char*)0},
#line 161 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.IPv6PrivacyExtensions",                   config_parse_ipv6_privacy_extensions,           0,                                      offsetof(Network, ipv6_privacy_extensions)},
      {(char*)0},
#line 553 "../systemd/src/network/networkd-network-gperf.gperf"
      {"EnhancedTransmissionSelection.PriorityMap",       config_parse_ets_prio,                          QDISC_KIND_ETS,                         0},
      {(char*)0}, {(char*)0},
#line 506 "../systemd/src/network/networkd-network-gperf.gperf"
      {"MobileNetwork.AllowRoaming",                      config_parse_bool,                              0,                                      offsetof(Network, mm_allow_roaming)},
      {(char*)0},
#line 482 "../systemd/src/network/networkd-network-gperf.gperf"
      {"CAN.PhaseBufferSegment1",                         config_parse_uint32,                            0,                                      offsetof(Network, can_phase_buffer_segment_1)},
      {(char*)0}, {(char*)0},
#line 302 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.FallbackLeaseLifetimeSec",                 config_parse_dhcp_fallback_lease_lifetime,      0,                                      0},
      {(char*)0},
#line 109 "../systemd/src/network/networkd-network-gperf.gperf"
      {"SR-IOV.VLANId",                                   config_parse_sr_iov_uint32,                     0,                                      offsetof(Network, sr_iov_by_section)},
      {(char*)0},
#line 80 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Match.Path",                                      config_parse_match_strv,                        0,                                      offsetof(Network, match.path)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 483 "../systemd/src/network/networkd-network-gperf.gperf"
      {"CAN.PhaseBufferSegment2",                         config_parse_uint32,                            0,                                      offsetof(Network, can_phase_buffer_segment_2)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 488 "../systemd/src/network/networkd-network-gperf.gperf"
      {"CAN.DataPropagationSegment",                      config_parse_uint32,                            0,                                      offsetof(Network, can_data_propagation_segment)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 468 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6Prefix.PreferredLifetimeSec",                 config_parse_prefix_lifetime,                   0,                                      0},
      {(char*)0}, {(char*)0},
#line 598 "../systemd/src/network/networkd-network-gperf.gperf"
      {"HeavyHitterFilter.Handle",                        config_parse_qdisc_handle,                      QDISC_KIND_HHF,                         0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 541 "../systemd/src/network/networkd-network-gperf.gperf"
      {"ControlledDelay.CEThresholdSec",                  config_parse_codel_usec,                        QDISC_KIND_CODEL,                       0},
      {(char*)0},
#line 135 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.DHCPRelay",                               config_parse_dhcp_relay_interface_mode,         0,                                      offsetof(Network, dhcp_relay_interface_mode)},
      {(char*)0},
#line 597 "../systemd/src/network/networkd-network-gperf.gperf"
      {"HeavyHitterFilter.Parent",                        config_parse_qdisc_parent,                      QDISC_KIND_HHF,                         0},
      {(char*)0},
#line 94 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Match.Credential",                                config_parse_net_condition,                     CONDITION_CREDENTIAL,                   offsetof(Network, conditions)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 693 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv6PrefixDelegation.Token",                    config_parse_address_generation_type,           0,                                      offsetof(Network, dhcp_pd_tokens)},
#line 599 "../systemd/src/network/networkd-network-gperf.gperf"
      {"HeavyHitterFilter.PacketLimit",                   config_parse_hhf_packet_limit,                  QDISC_KIND_HHF,                         0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 501 "../systemd/src/network/networkd-network-gperf.gperf"
      {"CAN.ClassicDataLengthCode",                       config_parse_can_control_mode,                  CAN_CTRLMODE_CC_LEN8_DLC,               0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 437 "../systemd/src/network/networkd-network-gperf.gperf"
      {"BridgeVLAN.VLAN",                                 config_parse_bridge_vlan_id_range,              0,                                      offsetof(Network, bridge_vlan_bitmap)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 684 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCP.ForceDHCPv6PDOtherInformation",              config_parse_warn_compat,                       DISABLED_LEGACY,                        0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 256 "../systemd/src/network/networkd-network-gperf.gperf"
      {"NextHop.Group",                                   config_parse_nexthop_section,                   NEXTHOP_GROUP,                          0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 101 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Link.Multicast",                                  config_parse_tristate,                          0,                                      offsetof(Network, multicast)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 253 "../systemd/src/network/networkd-network-gperf.gperf"
      {"NextHop.Family",                                  config_parse_nexthop_section,                   NEXTHOP_FAMILY,                         0},
#line 252 "../systemd/src/network/networkd-network-gperf.gperf"
      {"NextHop.Gateway",                                 config_parse_nexthop_section,                   NEXTHOP_GATEWAY,                        0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 522 "../systemd/src/network/networkd-network-gperf.gperf"
      {"CAKE.Bandwidth",                                  config_parse_cake_bandwidth,                    QDISC_KIND_CAKE,                        0},
      {(char*)0}, {(char*)0},
#line 511 "../systemd/src/network/networkd-network-gperf.gperf"
      {"MobileNetwork.Password",                          config_parse_string,                            CONFIG_PARSE_STRING_SAFE_AND_ASCII,     offsetof(Network, mm_password)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 374 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.RelayAgentRemoteId",                   config_parse_dhcp_option,                       /* check_length= */ true,               offsetof(Network, dhcp_relay_remote_id) /* deprecated */},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 656 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6PrefixDelegation.DNS",                        config_parse_radv_dns,                          0,                                      0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 115 "../systemd/src/network/networkd-network-gperf.gperf"
      {"SR-IOV.LinkState",                                config_parse_sr_iov_link_state,                 0,                                      offsetof(Network, sr_iov_by_section)},
      {(char*)0},
#line 677 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCP.DUIDType",                                   config_parse_network_duid_type,                 0,                                      0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 304 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv4.UnassignedSubnetPolicy",                   config_parse_dhcp_pd_prefix_route_type,         0,                                      offsetof(Network, dhcp_6rd_prefix_route_type)},
#line 388 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPServer.EmitLPR",                              config_parse_bool,                              0,                                      offsetof(Network, dhcp_server_emit[SD_DHCP_LEASE_LPR].emit)},
      {(char*)0},
#line 467 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6Prefix.ValidLifetimeSec",                     config_parse_prefix_lifetime,                   0,                                      0},
#line 332 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.RapidCommit",                              config_parse_bool,                              0,                                      offsetof(Network, dhcp6_use_rapid_commit)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 243 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Route.HopLimit",                                  config_parse_route_section,                     ROUTE_METRIC_HOPLIMIT,                  0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 606 "../systemd/src/network/networkd-network-gperf.gperf"
      {"HierarchyTokenBucketClass.Priority",              config_parse_htb_class_u32,                     TCLASS_KIND_HTB,                        0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 608 "../systemd/src/network/networkd-network-gperf.gperf"
      {"HierarchyTokenBucketClass.MTUBytes",              config_parse_htb_class_size,                    TCLASS_KIND_HTB,                        0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 204 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6AddressLabel.Label",                          config_parse_ipv6_address_label_section,        IPV6_ADDRESS_LABEL,                     0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 664 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCP.UseMTU",                                     config_parse_bool,                              0,                                      offsetof(Network, dhcp_use_mtu)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 576 "../systemd/src/network/networkd-network-gperf.gperf"
      {"FairQueueing.OrphanMask",                         config_parse_fq_u32,                            QDISC_KIND_FQ,                          0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 78 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Match.MACAddress",                                config_parse_hw_addrs,                          0,                                      offsetof(Network, match.hw_addr)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 116 "../systemd/src/network/networkd-network-gperf.gperf"
      {"SR-IOV.MACAddress",                               config_parse_sr_iov_mac,                        0,                                      offsetof(Network, sr_iov_by_section)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 176 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Network.IPv4ProxyARPPrivateVLAN",                 config_parse_tristate,                          0,                                      offsetof(Network, proxy_arp_pvlan)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 476 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6PREF64Prefix.LifetimeSec",                    config_parse_pref64_prefix_lifetime,            0,                                      0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 91 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Match.KernelCommandLine",                         config_parse_net_condition,                     CONDITION_KERNEL_COMMAND_LINE,          offsetof(Network, conditions)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 105 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Link.ActivationPolicy",                           config_parse_activation_policy,                 0,                                      offsetof(Network, activation_policy)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 525 "../systemd/src/network/networkd-network-gperf.gperf"
      {"CAKE.MPUBytes",                                   config_parse_cake_mpu,                          QDISC_KIND_CAKE,                        0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 429 "../systemd/src/network/networkd-network-gperf.gperf"
      {"BridgeFDB.VLANId",                                config_parse_fdb_vlan_id,                       0,                                      0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 591 "../systemd/src/network/networkd-network-gperf.gperf"
      {"FlowQueuePIE.PacketLimit",                        config_parse_fq_pie_packet_limit,               QDISC_KIND_FQ_PIE,                      0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 97 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Link.MACAddress",                                 config_parse_hw_addr,                           0,                                      offsetof(Network, hw_addr)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 79 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Match.PermanentMACAddress",                       config_parse_hw_addrs,                          0,                                      offsetof(Network, match.permanent_hw_addr)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 438 "../systemd/src/network/networkd-network-gperf.gperf"
      {"BridgeVLAN.EgressUntagged",                       config_parse_bridge_vlan_id_range,              0,                                      offsetof(Network, bridge_vlan_untagged_bitmap)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 434 "../systemd/src/network/networkd-network-gperf.gperf"
      {"BridgeMDB.MulticastGroupAddress",                 config_parse_mdb_group_address,                 0,                                      0},
      {(char*)0}, {(char*)0},
#line 104 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Link.Unmanaged",                                  config_parse_bool,                              0,                                      offsetof(Network, unmanaged)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 222 "../systemd/src/network/networkd-network-gperf.gperf"
      {"RoutingPolicyRule.Family",                        config_parse_routing_policy_rule,               ROUTING_POLICY_RULE_FAMILY,             0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 513 "../systemd/src/network/networkd-network-gperf.gperf"
      {"MobileNetwork.RouteMetric",                       config_parse_mm_route_metric,                   0,                                      0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 206 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Neighbor.LinkLayerAddress",                       config_parse_neighbor_section,                  NEIGHBOR_LINK_LAYER_ADDRESS,            0},
      {(char*)0},
#line 508 "../systemd/src/network/networkd-network-gperf.gperf"
      {"MobileNetwork.IPFamily",                          config_parse_mm_ip_family,                      0,                                      offsetof(Network, mm_ip_family)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 692 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv6PrefixDelegation.ManageTemporaryAddress",   config_parse_bool,                              0,                                      offsetof(Network, dhcp_pd_manage_temporary_address)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 475 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6PREF64Prefix.Prefix",                         config_parse_pref64_prefix,                     0,                                      0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 326 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv6.UnassignedSubnetPolicy",                   config_parse_dhcp_pd_prefix_route_type,         0,                                      offsetof(Network, dhcp6_pd_prefix_route_type)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 491 "../systemd/src/network/networkd-network-gperf.gperf"
      {"CAN.DataSyncJumpWidth",                           config_parse_uint32,                            0,                                      offsetof(Network, can_data_sync_jump_width)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 484 "../systemd/src/network/networkd-network-gperf.gperf"
      {"CAN.SyncJumpWidth",                               config_parse_uint32,                            0,                                      offsetof(Network, can_sync_jump_width)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 689 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv6PrefixDelegation.SubnetId",                 config_parse_dhcp_pd_subnet_id,                 0,                                      offsetof(Network, dhcp_pd_subnet_id)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 694 "../systemd/src/network/networkd-network-gperf.gperf"
      {"DHCPv6PrefixDelegation.RouteMetric",              config_parse_uint32,                            0,                                      offsetof(Network, dhcp_pd_route_metric)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 203 "../systemd/src/network/networkd-network-gperf.gperf"
      {"IPv6AddressLabel.Prefix",                         config_parse_ipv6_address_label_section,        IPV6_ADDRESS_LABEL_PREFIX,              0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 88 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Match.Property",                                  config_parse_match_property,                    0,                                      offsetof(Network, match.property)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 533 "../systemd/src/network/networkd-network-gperf.gperf"
      {"CAKE.SplitGSO",                                   config_parse_cake_tristate,                     QDISC_KIND_CAKE,                        0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 435 "../systemd/src/network/networkd-network-gperf.gperf"
      {"BridgeMDB.VLANId",                                config_parse_mdb_vlan_id,                       0,                                      0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 98 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Link.MTUBytes",                                   config_parse_mtu,                               AF_UNSPEC,                              offsetof(Network, mtu)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 112 "../systemd/src/network/networkd-network-gperf.gperf"
      {"SR-IOV.MACSpoofCheck",                            config_parse_sr_iov_boolean,                    0,                                      offsetof(Network, sr_iov_by_section)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 99 "../systemd/src/network/networkd-network-gperf.gperf"
      {"Link.Group",                                      config_parse_link_group,                        0,                                      0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 509 "../systemd/src/network/networkd-network-gperf.gperf"
      {"MobileNetwork.OperatorId",                        config_parse_string,                            CONFIG_PARSE_STRING_SAFE_AND_ASCII,     offsetof(Network, mm_operator_id)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 514 "../systemd/src/network/networkd-network-gperf.gperf"
      {"MobileNetwork.UseGateway",                        config_parse_tristate,                          0,                                      offsetof(Network, mm_use_gateway)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 113 "../systemd/src/network/networkd-network-gperf.gperf"
      {"SR-IOV.QueryReceiveSideScaling",                  config_parse_sr_iov_boolean,                    0,                                      offsetof(Network, sr_iov_by_section)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 477 "../systemd/src/network/networkd-network-gperf.gperf"
      {"LLDP.MUDURL",                                     config_parse_mud_url,                           0,                                      offsetof(Network, lldp_mudurl)}
    };
#if (defined __GNUC__ && __GNUC__ + (__GNUC_MINOR__ >= 6) > 4) || (defined __clang__ && __clang_major__ >= 3)
#pragma GCC diagnostic pop
#endif

  if (len <= MAX_WORD_LENGTH && len >= MIN_WORD_LENGTH)
    {
      register unsigned int key = network_network_gperf_hash (str, len);

      if (key <= MAX_HASH_VALUE)
        {
          register const char *s = wordlist[key].section_and_lvalue;

          if (s && *str == *s && !strcmp (str + 1, s + 1))
            return &wordlist[key];
        }
    }
  return (struct ConfigPerfItem *) 0;
}
